'use strict';

var antd = require('antd');

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var axios$2 = {exports: {}};

var bind$2 = function bind(fn, thisArg) {
  return function wrap() {
    var args = new Array(arguments.length);

    for (var i = 0; i < args.length; i++) {
      args[i] = arguments[i];
    }

    return fn.apply(thisArg, args);
  };
};

var bind$1 = bind$2;
/*global toString:true*/
// utils is a library of generic helper functions non-specific to axios

var toString = Object.prototype.toString;
/**
 * Determine if a value is an Array
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Array, otherwise false
 */

function isArray(val) {
  return toString.call(val) === '[object Array]';
}
/**
 * Determine if a value is undefined
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if the value is undefined, otherwise false
 */


function isUndefined(val) {
  return typeof val === 'undefined';
}
/**
 * Determine if a value is a Buffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Buffer, otherwise false
 */


function isBuffer(val) {
  return val !== null && !isUndefined(val) && val.constructor !== null && !isUndefined(val.constructor) && typeof val.constructor.isBuffer === 'function' && val.constructor.isBuffer(val);
}
/**
 * Determine if a value is an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an ArrayBuffer, otherwise false
 */


function isArrayBuffer(val) {
  return toString.call(val) === '[object ArrayBuffer]';
}
/**
 * Determine if a value is a FormData
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an FormData, otherwise false
 */


function isFormData(val) {
  return typeof FormData !== 'undefined' && val instanceof FormData;
}
/**
 * Determine if a value is a view on an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a view on an ArrayBuffer, otherwise false
 */


function isArrayBufferView(val) {
  var result;

  if (typeof ArrayBuffer !== 'undefined' && ArrayBuffer.isView) {
    result = ArrayBuffer.isView(val);
  } else {
    result = val && val.buffer && val.buffer instanceof ArrayBuffer;
  }

  return result;
}
/**
 * Determine if a value is a String
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a String, otherwise false
 */


function isString(val) {
  return typeof val === 'string';
}
/**
 * Determine if a value is a Number
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Number, otherwise false
 */


function isNumber(val) {
  return typeof val === 'number';
}
/**
 * Determine if a value is an Object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Object, otherwise false
 */


function isObject(val) {
  return val !== null && typeof val === 'object';
}
/**
 * Determine if a value is a plain Object
 *
 * @param {Object} val The value to test
 * @return {boolean} True if value is a plain Object, otherwise false
 */


function isPlainObject(val) {
  if (toString.call(val) !== '[object Object]') {
    return false;
  }

  var prototype = Object.getPrototypeOf(val);
  return prototype === null || prototype === Object.prototype;
}
/**
 * Determine if a value is a Date
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Date, otherwise false
 */


function isDate(val) {
  return toString.call(val) === '[object Date]';
}
/**
 * Determine if a value is a File
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a File, otherwise false
 */


function isFile(val) {
  return toString.call(val) === '[object File]';
}
/**
 * Determine if a value is a Blob
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Blob, otherwise false
 */


function isBlob(val) {
  return toString.call(val) === '[object Blob]';
}
/**
 * Determine if a value is a Function
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Function, otherwise false
 */


function isFunction(val) {
  return toString.call(val) === '[object Function]';
}
/**
 * Determine if a value is a Stream
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Stream, otherwise false
 */


function isStream(val) {
  return isObject(val) && isFunction(val.pipe);
}
/**
 * Determine if a value is a URLSearchParams object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a URLSearchParams object, otherwise false
 */


function isURLSearchParams(val) {
  return typeof URLSearchParams !== 'undefined' && val instanceof URLSearchParams;
}
/**
 * Trim excess whitespace off the beginning and end of a string
 *
 * @param {String} str The String to trim
 * @returns {String} The String freed of excess whitespace
 */


function trim(str) {
  return str.replace(/^\s*/, '').replace(/\s*$/, '');
}
/**
 * Determine if we're running in a standard browser environment
 *
 * This allows axios to run in a web worker, and react-native.
 * Both environments support XMLHttpRequest, but not fully standard globals.
 *
 * web workers:
 *  typeof window -> undefined
 *  typeof document -> undefined
 *
 * react-native:
 *  navigator.product -> 'ReactNative'
 * nativescript
 *  navigator.product -> 'NativeScript' or 'NS'
 */


function isStandardBrowserEnv() {
  if (typeof navigator !== 'undefined' && (navigator.product === 'ReactNative' || navigator.product === 'NativeScript' || navigator.product === 'NS')) {
    return false;
  }

  return typeof window !== 'undefined' && typeof document !== 'undefined';
}
/**
 * Iterate over an Array or an Object invoking a function for each item.
 *
 * If `obj` is an Array callback will be called passing
 * the value, index, and complete array for each item.
 *
 * If 'obj' is an Object callback will be called passing
 * the value, key, and complete object for each property.
 *
 * @param {Object|Array} obj The object to iterate
 * @param {Function} fn The callback to invoke for each item
 */


function forEach(obj, fn) {
  // Don't bother if no value provided
  if (obj === null || typeof obj === 'undefined') {
    return;
  } // Force an array if not already something iterable


  if (typeof obj !== 'object') {
    /*eslint no-param-reassign:0*/
    obj = [obj];
  }

  if (isArray(obj)) {
    // Iterate over array values
    for (var i = 0, l = obj.length; i < l; i++) {
      fn.call(null, obj[i], i, obj);
    }
  } else {
    // Iterate over object keys
    for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        fn.call(null, obj[key], key, obj);
      }
    }
  }
}
/**
 * Accepts varargs expecting each argument to be an object, then
 * immutably merges the properties of each object and returns result.
 *
 * When multiple objects contain the same key the later object in
 * the arguments list will take precedence.
 *
 * Example:
 *
 * ```js
 * var result = merge({foo: 123}, {foo: 456});
 * console.log(result.foo); // outputs 456
 * ```
 *
 * @param {Object} obj1 Object to merge
 * @returns {Object} Result of all merge properties
 */


function merge()
/* obj1, obj2, obj3, ... */
{
  var result = {};

  function assignValue(val, key) {
    if (isPlainObject(result[key]) && isPlainObject(val)) {
      result[key] = merge(result[key], val);
    } else if (isPlainObject(val)) {
      result[key] = merge({}, val);
    } else if (isArray(val)) {
      result[key] = val.slice();
    } else {
      result[key] = val;
    }
  }

  for (var i = 0, l = arguments.length; i < l; i++) {
    forEach(arguments[i], assignValue);
  }

  return result;
}
/**
 * Extends object a by mutably adding to it the properties of object b.
 *
 * @param {Object} a The object to be extended
 * @param {Object} b The object to copy properties from
 * @param {Object} thisArg The object to bind function to
 * @return {Object} The resulting value of object a
 */


function extend(a, b, thisArg) {
  forEach(b, function assignValue(val, key) {
    if (thisArg && typeof val === 'function') {
      a[key] = bind$1(val, thisArg);
    } else {
      a[key] = val;
    }
  });
  return a;
}
/**
 * Remove byte order marker. This catches EF BB BF (the UTF-8 BOM)
 *
 * @param {string} content with BOM
 * @return {string} content value without BOM
 */


function stripBOM(content) {
  if (content.charCodeAt(0) === 0xFEFF) {
    content = content.slice(1);
  }

  return content;
}

var utils$d = {
  isArray: isArray,
  isArrayBuffer: isArrayBuffer,
  isBuffer: isBuffer,
  isFormData: isFormData,
  isArrayBufferView: isArrayBufferView,
  isString: isString,
  isNumber: isNumber,
  isObject: isObject,
  isPlainObject: isPlainObject,
  isUndefined: isUndefined,
  isDate: isDate,
  isFile: isFile,
  isBlob: isBlob,
  isFunction: isFunction,
  isStream: isStream,
  isURLSearchParams: isURLSearchParams,
  isStandardBrowserEnv: isStandardBrowserEnv,
  forEach: forEach,
  merge: merge,
  extend: extend,
  trim: trim,
  stripBOM: stripBOM
};

var utils$c = utils$d;

function encode(val) {
  return encodeURIComponent(val).replace(/%3A/gi, ':').replace(/%24/g, '$').replace(/%2C/gi, ',').replace(/%20/g, '+').replace(/%5B/gi, '[').replace(/%5D/gi, ']');
}
/**
 * Build a URL by appending params to the end
 *
 * @param {string} url The base of the url (e.g., http://www.google.com)
 * @param {object} [params] The params to be appended
 * @returns {string} The formatted url
 */


var buildURL$2 = function buildURL(url, params, paramsSerializer) {
  /*eslint no-param-reassign:0*/
  if (!params) {
    return url;
  }

  var serializedParams;

  if (paramsSerializer) {
    serializedParams = paramsSerializer(params);
  } else if (utils$c.isURLSearchParams(params)) {
    serializedParams = params.toString();
  } else {
    var parts = [];
    utils$c.forEach(params, function serialize(val, key) {
      if (val === null || typeof val === 'undefined') {
        return;
      }

      if (utils$c.isArray(val)) {
        key = key + '[]';
      } else {
        val = [val];
      }

      utils$c.forEach(val, function parseValue(v) {
        if (utils$c.isDate(v)) {
          v = v.toISOString();
        } else if (utils$c.isObject(v)) {
          v = JSON.stringify(v);
        }

        parts.push(encode(key) + '=' + encode(v));
      });
    });
    serializedParams = parts.join('&');
  }

  if (serializedParams) {
    var hashmarkIndex = url.indexOf('#');

    if (hashmarkIndex !== -1) {
      url = url.slice(0, hashmarkIndex);
    }

    url += (url.indexOf('?') === -1 ? '?' : '&') + serializedParams;
  }

  return url;
};

var utils$b = utils$d;

function InterceptorManager$1() {
  this.handlers = [];
}
/**
 * Add a new interceptor to the stack
 *
 * @param {Function} fulfilled The function to handle `then` for a `Promise`
 * @param {Function} rejected The function to handle `reject` for a `Promise`
 *
 * @return {Number} An ID used to remove interceptor later
 */


InterceptorManager$1.prototype.use = function use(fulfilled, rejected) {
  this.handlers.push({
    fulfilled: fulfilled,
    rejected: rejected
  });
  return this.handlers.length - 1;
};
/**
 * Remove an interceptor from the stack
 *
 * @param {Number} id The ID that was returned by `use`
 */


InterceptorManager$1.prototype.eject = function eject(id) {
  if (this.handlers[id]) {
    this.handlers[id] = null;
  }
};
/**
 * Iterate over all the registered interceptors
 *
 * This method is particularly useful for skipping over any
 * interceptors that may have become `null` calling `eject`.
 *
 * @param {Function} fn The function to call for each interceptor
 */


InterceptorManager$1.prototype.forEach = function forEach(fn) {
  utils$b.forEach(this.handlers, function forEachHandler(h) {
    if (h !== null) {
      fn(h);
    }
  });
};

var InterceptorManager_1 = InterceptorManager$1;

var utils$a = utils$d;
/**
 * Transform the data for a request or a response
 *
 * @param {Object|String} data The data to be transformed
 * @param {Array} headers The headers for the request or response
 * @param {Array|Function} fns A single function or Array of functions
 * @returns {*} The resulting transformed data
 */

var transformData$1 = function transformData(data, headers, fns) {
  /*eslint no-param-reassign:0*/
  utils$a.forEach(fns, function transform(fn) {
    data = fn(data, headers);
  });
  return data;
};

var isCancel$1 = function isCancel(value) {
  return !!(value && value.__CANCEL__);
};

var utils$9 = utils$d;

var normalizeHeaderName$1 = function normalizeHeaderName(headers, normalizedName) {
  utils$9.forEach(headers, function processHeader(value, name) {
    if (name !== normalizedName && name.toUpperCase() === normalizedName.toUpperCase()) {
      headers[normalizedName] = value;
      delete headers[name];
    }
  });
};

/**
 * Update an Error with the specified config, error code, and response.
 *
 * @param {Error} error The error to update.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The error.
 */


var enhanceError$1 = function enhanceError(error, config, code, request, response) {
  error.config = config;

  if (code) {
    error.code = code;
  }

  error.request = request;
  error.response = response;
  error.isAxiosError = true;

  error.toJSON = function toJSON() {
    return {
      // Standard
      message: this.message,
      name: this.name,
      // Microsoft
      description: this.description,
      number: this.number,
      // Mozilla
      fileName: this.fileName,
      lineNumber: this.lineNumber,
      columnNumber: this.columnNumber,
      stack: this.stack,
      // Axios
      config: this.config,
      code: this.code
    };
  };

  return error;
};

var enhanceError = enhanceError$1;
/**
 * Create an Error with the specified message, config, error code, request and response.
 *
 * @param {string} message The error message.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The created error.
 */

var createError$2 = function createError(message, config, code, request, response) {
  var error = new Error(message);
  return enhanceError(error, config, code, request, response);
};

var createError$1 = createError$2;
/**
 * Resolve or reject a Promise based on response status.
 *
 * @param {Function} resolve A function that resolves the promise.
 * @param {Function} reject A function that rejects the promise.
 * @param {object} response The response.
 */

var settle$1 = function settle(resolve, reject, response) {
  var validateStatus = response.config.validateStatus;

  if (!response.status || !validateStatus || validateStatus(response.status)) {
    resolve(response);
  } else {
    reject(createError$1('Request failed with status code ' + response.status, response.config, null, response.request, response));
  }
};

var utils$8 = utils$d;
var cookies$1 = utils$8.isStandardBrowserEnv() ? // Standard browser envs support document.cookie
function standardBrowserEnv() {
  return {
    write: function write(name, value, expires, path, domain, secure) {
      var cookie = [];
      cookie.push(name + '=' + encodeURIComponent(value));

      if (utils$8.isNumber(expires)) {
        cookie.push('expires=' + new Date(expires).toGMTString());
      }

      if (utils$8.isString(path)) {
        cookie.push('path=' + path);
      }

      if (utils$8.isString(domain)) {
        cookie.push('domain=' + domain);
      }

      if (secure === true) {
        cookie.push('secure');
      }

      document.cookie = cookie.join('; ');
    },
    read: function read(name) {
      var match = document.cookie.match(new RegExp('(^|;\\s*)(' + name + ')=([^;]*)'));
      return match ? decodeURIComponent(match[3]) : null;
    },
    remove: function remove(name) {
      this.write(name, '', Date.now() - 86400000);
    }
  };
}() : // Non standard browser env (web workers, react-native) lack needed support.
function nonStandardBrowserEnv() {
  return {
    write: function write() {},
    read: function read() {
      return null;
    },
    remove: function remove() {}
  };
}();

/**
 * Determines whether the specified URL is absolute
 *
 * @param {string} url The URL to test
 * @returns {boolean} True if the specified URL is absolute, otherwise false
 */


var isAbsoluteURL$1 = function isAbsoluteURL(url) {
  // A URL is considered absolute if it begins with "<scheme>://" or "//" (protocol-relative URL).
  // RFC 3986 defines scheme name as a sequence of characters beginning with a letter and followed
  // by any combination of letters, digits, plus, period, or hyphen.
  return /^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(url);
};

/**
 * Creates a new URL by combining the specified URLs
 *
 * @param {string} baseURL The base URL
 * @param {string} relativeURL The relative URL
 * @returns {string} The combined URL
 */


var combineURLs$1 = function combineURLs(baseURL, relativeURL) {
  return relativeURL ? baseURL.replace(/\/+$/, '') + '/' + relativeURL.replace(/^\/+/, '') : baseURL;
};

var isAbsoluteURL = isAbsoluteURL$1;
var combineURLs = combineURLs$1;
/**
 * Creates a new URL by combining the baseURL with the requestedURL,
 * only when the requestedURL is not already an absolute URL.
 * If the requestURL is absolute, this function returns the requestedURL untouched.
 *
 * @param {string} baseURL The base URL
 * @param {string} requestedURL Absolute or relative URL to combine
 * @returns {string} The combined full path
 */

var buildFullPath$1 = function buildFullPath(baseURL, requestedURL) {
  if (baseURL && !isAbsoluteURL(requestedURL)) {
    return combineURLs(baseURL, requestedURL);
  }

  return requestedURL;
};

var utils$7 = utils$d; // Headers whose duplicates are ignored by node
// c.f. https://nodejs.org/api/http.html#http_message_headers

var ignoreDuplicateOf = ['age', 'authorization', 'content-length', 'content-type', 'etag', 'expires', 'from', 'host', 'if-modified-since', 'if-unmodified-since', 'last-modified', 'location', 'max-forwards', 'proxy-authorization', 'referer', 'retry-after', 'user-agent'];
/**
 * Parse headers into an object
 *
 * ```
 * Date: Wed, 27 Aug 2014 08:58:49 GMT
 * Content-Type: application/json
 * Connection: keep-alive
 * Transfer-Encoding: chunked
 * ```
 *
 * @param {String} headers Headers needing to be parsed
 * @returns {Object} Headers parsed into an object
 */

var parseHeaders$1 = function parseHeaders(headers) {
  var parsed = {};
  var key;
  var val;
  var i;

  if (!headers) {
    return parsed;
  }

  utils$7.forEach(headers.split('\n'), function parser(line) {
    i = line.indexOf(':');
    key = utils$7.trim(line.substr(0, i)).toLowerCase();
    val = utils$7.trim(line.substr(i + 1));

    if (key) {
      if (parsed[key] && ignoreDuplicateOf.indexOf(key) >= 0) {
        return;
      }

      if (key === 'set-cookie') {
        parsed[key] = (parsed[key] ? parsed[key] : []).concat([val]);
      } else {
        parsed[key] = parsed[key] ? parsed[key] + ', ' + val : val;
      }
    }
  });
  return parsed;
};

var utils$6 = utils$d;
var isURLSameOrigin$1 = utils$6.isStandardBrowserEnv() ? // Standard browser envs have full support of the APIs needed to test
// whether the request URL is of the same origin as current location.
function standardBrowserEnv() {
  var msie = /(msie|trident)/i.test(navigator.userAgent);
  var urlParsingNode = document.createElement('a');
  var originURL;
  /**
  * Parse a URL to discover it's components
  *
  * @param {String} url The URL to be parsed
  * @returns {Object}
  */

  function resolveURL(url) {
    var href = url;

    if (msie) {
      // IE needs attribute set twice to normalize properties
      urlParsingNode.setAttribute('href', href);
      href = urlParsingNode.href;
    }

    urlParsingNode.setAttribute('href', href); // urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils

    return {
      href: urlParsingNode.href,
      protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
      host: urlParsingNode.host,
      search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
      hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
      hostname: urlParsingNode.hostname,
      port: urlParsingNode.port,
      pathname: urlParsingNode.pathname.charAt(0) === '/' ? urlParsingNode.pathname : '/' + urlParsingNode.pathname
    };
  }

  originURL = resolveURL(window.location.href);
  /**
  * Determine if a URL shares the same origin as the current location
  *
  * @param {String} requestURL The URL to test
  * @returns {boolean} True if URL shares the same origin, otherwise false
  */

  return function isURLSameOrigin(requestURL) {
    var parsed = utils$6.isString(requestURL) ? resolveURL(requestURL) : requestURL;
    return parsed.protocol === originURL.protocol && parsed.host === originURL.host;
  };
}() : // Non standard browser envs (web workers, react-native) lack needed support.
function nonStandardBrowserEnv() {
  return function isURLSameOrigin() {
    return true;
  };
}();

var utils$5 = utils$d;
var settle = settle$1;
var cookies = cookies$1;
var buildURL$1 = buildURL$2;
var buildFullPath = buildFullPath$1;
var parseHeaders = parseHeaders$1;
var isURLSameOrigin = isURLSameOrigin$1;
var createError = createError$2;

var xhr = function xhrAdapter(config) {
  return new Promise(function dispatchXhrRequest(resolve, reject) {
    var requestData = config.data;
    var requestHeaders = config.headers;

    if (utils$5.isFormData(requestData)) {
      delete requestHeaders['Content-Type']; // Let the browser set it
    }

    var request = new XMLHttpRequest(); // HTTP basic authentication

    if (config.auth) {
      var username = config.auth.username || '';
      var password = config.auth.password ? unescape(encodeURIComponent(config.auth.password)) : '';
      requestHeaders.Authorization = 'Basic ' + btoa(username + ':' + password);
    }

    var fullPath = buildFullPath(config.baseURL, config.url);
    request.open(config.method.toUpperCase(), buildURL$1(fullPath, config.params, config.paramsSerializer), true); // Set the request timeout in MS

    request.timeout = config.timeout; // Listen for ready state

    request.onreadystatechange = function handleLoad() {
      if (!request || request.readyState !== 4) {
        return;
      } // The request errored out and we didn't get a response, this will be
      // handled by onerror instead
      // With one exception: request that using file: protocol, most browsers
      // will return status as 0 even though it's a successful request


      if (request.status === 0 && !(request.responseURL && request.responseURL.indexOf('file:') === 0)) {
        return;
      } // Prepare the response


      var responseHeaders = 'getAllResponseHeaders' in request ? parseHeaders(request.getAllResponseHeaders()) : null;
      var responseData = !config.responseType || config.responseType === 'text' ? request.responseText : request.response;
      var response = {
        data: responseData,
        status: request.status,
        statusText: request.statusText,
        headers: responseHeaders,
        config: config,
        request: request
      };
      settle(resolve, reject, response); // Clean up request

      request = null;
    }; // Handle browser request cancellation (as opposed to a manual cancellation)


    request.onabort = function handleAbort() {
      if (!request) {
        return;
      }

      reject(createError('Request aborted', config, 'ECONNABORTED', request)); // Clean up request

      request = null;
    }; // Handle low level network errors


    request.onerror = function handleError() {
      // Real errors are hidden from us by the browser
      // onerror should only fire if it's a network error
      reject(createError('Network Error', config, null, request)); // Clean up request

      request = null;
    }; // Handle timeout


    request.ontimeout = function handleTimeout() {
      var timeoutErrorMessage = 'timeout of ' + config.timeout + 'ms exceeded';

      if (config.timeoutErrorMessage) {
        timeoutErrorMessage = config.timeoutErrorMessage;
      }

      reject(createError(timeoutErrorMessage, config, 'ECONNABORTED', request)); // Clean up request

      request = null;
    }; // Add xsrf header
    // This is only done if running in a standard browser environment.
    // Specifically not if we're in a web worker, or react-native.


    if (utils$5.isStandardBrowserEnv()) {
      // Add xsrf header
      var xsrfValue = (config.withCredentials || isURLSameOrigin(fullPath)) && config.xsrfCookieName ? cookies.read(config.xsrfCookieName) : undefined;

      if (xsrfValue) {
        requestHeaders[config.xsrfHeaderName] = xsrfValue;
      }
    } // Add headers to the request


    if ('setRequestHeader' in request) {
      utils$5.forEach(requestHeaders, function setRequestHeader(val, key) {
        if (typeof requestData === 'undefined' && key.toLowerCase() === 'content-type') {
          // Remove Content-Type if data is undefined
          delete requestHeaders[key];
        } else {
          // Otherwise add header to the request
          request.setRequestHeader(key, val);
        }
      });
    } // Add withCredentials to request if needed


    if (!utils$5.isUndefined(config.withCredentials)) {
      request.withCredentials = !!config.withCredentials;
    } // Add responseType to request if needed


    if (config.responseType) {
      try {
        request.responseType = config.responseType;
      } catch (e) {
        // Expected DOMException thrown by browsers not compatible XMLHttpRequest Level 2.
        // But, this can be suppressed for 'json' type as it can be parsed by default 'transformResponse' function.
        if (config.responseType !== 'json') {
          throw e;
        }
      }
    } // Handle progress if needed


    if (typeof config.onDownloadProgress === 'function') {
      request.addEventListener('progress', config.onDownloadProgress);
    } // Not all browsers support upload events


    if (typeof config.onUploadProgress === 'function' && request.upload) {
      request.upload.addEventListener('progress', config.onUploadProgress);
    }

    if (config.cancelToken) {
      // Handle cancellation
      config.cancelToken.promise.then(function onCanceled(cancel) {
        if (!request) {
          return;
        }

        request.abort();
        reject(cancel); // Clean up request

        request = null;
      });
    }

    if (!requestData) {
      requestData = null;
    } // Send the request


    request.send(requestData);
  });
};

var utils$4 = utils$d;
var normalizeHeaderName = normalizeHeaderName$1;
var DEFAULT_CONTENT_TYPE = {
  'Content-Type': 'application/x-www-form-urlencoded'
};

function setContentTypeIfUnset(headers, value) {
  if (!utils$4.isUndefined(headers) && utils$4.isUndefined(headers['Content-Type'])) {
    headers['Content-Type'] = value;
  }
}

function getDefaultAdapter() {
  var adapter;

  if (typeof XMLHttpRequest !== 'undefined') {
    // For browsers use XHR adapter
    adapter = xhr;
  } else if (typeof process !== 'undefined' && Object.prototype.toString.call(process) === '[object process]') {
    // For node use HTTP adapter
    adapter = xhr;
  }

  return adapter;
}

var defaults$2 = {
  adapter: getDefaultAdapter(),
  transformRequest: [function transformRequest(data, headers) {
    normalizeHeaderName(headers, 'Accept');
    normalizeHeaderName(headers, 'Content-Type');

    if (utils$4.isFormData(data) || utils$4.isArrayBuffer(data) || utils$4.isBuffer(data) || utils$4.isStream(data) || utils$4.isFile(data) || utils$4.isBlob(data)) {
      return data;
    }

    if (utils$4.isArrayBufferView(data)) {
      return data.buffer;
    }

    if (utils$4.isURLSearchParams(data)) {
      setContentTypeIfUnset(headers, 'application/x-www-form-urlencoded;charset=utf-8');
      return data.toString();
    }

    if (utils$4.isObject(data)) {
      setContentTypeIfUnset(headers, 'application/json;charset=utf-8');
      return JSON.stringify(data);
    }

    return data;
  }],
  transformResponse: [function transformResponse(data) {
    /*eslint no-param-reassign:0*/
    if (typeof data === 'string') {
      try {
        data = JSON.parse(data);
      } catch (e) {
        /* Ignore */
      }
    }

    return data;
  }],

  /**
   * A timeout in milliseconds to abort a request. If set to 0 (default) a
   * timeout is not created.
   */
  timeout: 0,
  xsrfCookieName: 'XSRF-TOKEN',
  xsrfHeaderName: 'X-XSRF-TOKEN',
  maxContentLength: -1,
  maxBodyLength: -1,
  validateStatus: function validateStatus(status) {
    return status >= 200 && status < 300;
  }
};
defaults$2.headers = {
  common: {
    'Accept': 'application/json, text/plain, */*'
  }
};
utils$4.forEach(['delete', 'get', 'head'], function forEachMethodNoData(method) {
  defaults$2.headers[method] = {};
});
utils$4.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
  defaults$2.headers[method] = utils$4.merge(DEFAULT_CONTENT_TYPE);
});
var defaults_1 = defaults$2;

var utils$3 = utils$d;
var transformData = transformData$1;
var isCancel = isCancel$1;
var defaults$1 = defaults_1;
/**
 * Throws a `Cancel` if cancellation has been requested.
 */

function throwIfCancellationRequested(config) {
  if (config.cancelToken) {
    config.cancelToken.throwIfRequested();
  }
}
/**
 * Dispatch a request to the server using the configured adapter.
 *
 * @param {object} config The config that is to be used for the request
 * @returns {Promise} The Promise to be fulfilled
 */


var dispatchRequest$1 = function dispatchRequest(config) {
  throwIfCancellationRequested(config); // Ensure headers exist

  config.headers = config.headers || {}; // Transform request data

  config.data = transformData(config.data, config.headers, config.transformRequest); // Flatten headers

  config.headers = utils$3.merge(config.headers.common || {}, config.headers[config.method] || {}, config.headers);
  utils$3.forEach(['delete', 'get', 'head', 'post', 'put', 'patch', 'common'], function cleanHeaderConfig(method) {
    delete config.headers[method];
  });
  var adapter = config.adapter || defaults$1.adapter;
  return adapter(config).then(function onAdapterResolution(response) {
    throwIfCancellationRequested(config); // Transform response data

    response.data = transformData(response.data, response.headers, config.transformResponse);
    return response;
  }, function onAdapterRejection(reason) {
    if (!isCancel(reason)) {
      throwIfCancellationRequested(config); // Transform response data

      if (reason && reason.response) {
        reason.response.data = transformData(reason.response.data, reason.response.headers, config.transformResponse);
      }
    }

    return Promise.reject(reason);
  });
};

var utils$2 = utils$d;
/**
 * Config-specific merge-function which creates a new config-object
 * by merging two configuration objects together.
 *
 * @param {Object} config1
 * @param {Object} config2
 * @returns {Object} New object resulting from merging config2 to config1
 */

var mergeConfig$2 = function mergeConfig(config1, config2) {
  // eslint-disable-next-line no-param-reassign
  config2 = config2 || {};
  var config = {};
  var valueFromConfig2Keys = ['url', 'method', 'data'];
  var mergeDeepPropertiesKeys = ['headers', 'auth', 'proxy', 'params'];
  var defaultToConfig2Keys = ['baseURL', 'transformRequest', 'transformResponse', 'paramsSerializer', 'timeout', 'timeoutMessage', 'withCredentials', 'adapter', 'responseType', 'xsrfCookieName', 'xsrfHeaderName', 'onUploadProgress', 'onDownloadProgress', 'decompress', 'maxContentLength', 'maxBodyLength', 'maxRedirects', 'transport', 'httpAgent', 'httpsAgent', 'cancelToken', 'socketPath', 'responseEncoding'];
  var directMergeKeys = ['validateStatus'];

  function getMergedValue(target, source) {
    if (utils$2.isPlainObject(target) && utils$2.isPlainObject(source)) {
      return utils$2.merge(target, source);
    } else if (utils$2.isPlainObject(source)) {
      return utils$2.merge({}, source);
    } else if (utils$2.isArray(source)) {
      return source.slice();
    }

    return source;
  }

  function mergeDeepProperties(prop) {
    if (!utils$2.isUndefined(config2[prop])) {
      config[prop] = getMergedValue(config1[prop], config2[prop]);
    } else if (!utils$2.isUndefined(config1[prop])) {
      config[prop] = getMergedValue(undefined, config1[prop]);
    }
  }

  utils$2.forEach(valueFromConfig2Keys, function valueFromConfig2(prop) {
    if (!utils$2.isUndefined(config2[prop])) {
      config[prop] = getMergedValue(undefined, config2[prop]);
    }
  });
  utils$2.forEach(mergeDeepPropertiesKeys, mergeDeepProperties);
  utils$2.forEach(defaultToConfig2Keys, function defaultToConfig2(prop) {
    if (!utils$2.isUndefined(config2[prop])) {
      config[prop] = getMergedValue(undefined, config2[prop]);
    } else if (!utils$2.isUndefined(config1[prop])) {
      config[prop] = getMergedValue(undefined, config1[prop]);
    }
  });
  utils$2.forEach(directMergeKeys, function merge(prop) {
    if (prop in config2) {
      config[prop] = getMergedValue(config1[prop], config2[prop]);
    } else if (prop in config1) {
      config[prop] = getMergedValue(undefined, config1[prop]);
    }
  });
  var axiosKeys = valueFromConfig2Keys.concat(mergeDeepPropertiesKeys).concat(defaultToConfig2Keys).concat(directMergeKeys);
  var otherKeys = Object.keys(config1).concat(Object.keys(config2)).filter(function filterAxiosKeys(key) {
    return axiosKeys.indexOf(key) === -1;
  });
  utils$2.forEach(otherKeys, mergeDeepProperties);
  return config;
};

var utils$1 = utils$d;
var buildURL = buildURL$2;
var InterceptorManager = InterceptorManager_1;
var dispatchRequest = dispatchRequest$1;
var mergeConfig$1 = mergeConfig$2;
/**
 * Create a new instance of Axios
 *
 * @param {Object} instanceConfig The default config for the instance
 */

function Axios$1(instanceConfig) {
  this.defaults = instanceConfig;
  this.interceptors = {
    request: new InterceptorManager(),
    response: new InterceptorManager()
  };
}
/**
 * Dispatch a request
 *
 * @param {Object} config The config specific for this request (merged with this.defaults)
 */


Axios$1.prototype.request = function request(config) {
  /*eslint no-param-reassign:0*/
  // Allow for axios('example/url'[, config]) a la fetch API
  if (typeof config === 'string') {
    config = arguments[1] || {};
    config.url = arguments[0];
  } else {
    config = config || {};
  }

  config = mergeConfig$1(this.defaults, config); // Set config.method

  if (config.method) {
    config.method = config.method.toLowerCase();
  } else if (this.defaults.method) {
    config.method = this.defaults.method.toLowerCase();
  } else {
    config.method = 'get';
  } // Hook up interceptors middleware


  var chain = [dispatchRequest, undefined];
  var promise = Promise.resolve(config);
  this.interceptors.request.forEach(function unshiftRequestInterceptors(interceptor) {
    chain.unshift(interceptor.fulfilled, interceptor.rejected);
  });
  this.interceptors.response.forEach(function pushResponseInterceptors(interceptor) {
    chain.push(interceptor.fulfilled, interceptor.rejected);
  });

  while (chain.length) {
    promise = promise.then(chain.shift(), chain.shift());
  }

  return promise;
};

Axios$1.prototype.getUri = function getUri(config) {
  config = mergeConfig$1(this.defaults, config);
  return buildURL(config.url, config.params, config.paramsSerializer).replace(/^\?/, '');
}; // Provide aliases for supported request methods


utils$1.forEach(['delete', 'get', 'head', 'options'], function forEachMethodNoData(method) {
  /*eslint func-names:0*/
  Axios$1.prototype[method] = function (url, config) {
    return this.request(mergeConfig$1(config || {}, {
      method: method,
      url: url,
      data: (config || {}).data
    }));
  };
});
utils$1.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
  /*eslint func-names:0*/
  Axios$1.prototype[method] = function (url, data, config) {
    return this.request(mergeConfig$1(config || {}, {
      method: method,
      url: url,
      data: data
    }));
  };
});
var Axios_1 = Axios$1;

/**
 * A `Cancel` is an object that is thrown when an operation is canceled.
 *
 * @class
 * @param {string=} message The message.
 */


function Cancel$1(message) {
  this.message = message;
}

Cancel$1.prototype.toString = function toString() {
  return 'Cancel' + (this.message ? ': ' + this.message : '');
};

Cancel$1.prototype.__CANCEL__ = true;
var Cancel_1 = Cancel$1;

var Cancel = Cancel_1;
/**
 * A `CancelToken` is an object that can be used to request cancellation of an operation.
 *
 * @class
 * @param {Function} executor The executor function.
 */

function CancelToken(executor) {
  if (typeof executor !== 'function') {
    throw new TypeError('executor must be a function.');
  }

  var resolvePromise;
  this.promise = new Promise(function promiseExecutor(resolve) {
    resolvePromise = resolve;
  });
  var token = this;
  executor(function cancel(message) {
    if (token.reason) {
      // Cancellation has already been requested
      return;
    }

    token.reason = new Cancel(message);
    resolvePromise(token.reason);
  });
}
/**
 * Throws a `Cancel` if cancellation has been requested.
 */


CancelToken.prototype.throwIfRequested = function throwIfRequested() {
  if (this.reason) {
    throw this.reason;
  }
};
/**
 * Returns an object that contains a new `CancelToken` and a function that, when called,
 * cancels the `CancelToken`.
 */


CancelToken.source = function source() {
  var cancel;
  var token = new CancelToken(function executor(c) {
    cancel = c;
  });
  return {
    token: token,
    cancel: cancel
  };
};

var CancelToken_1 = CancelToken;

/**
 * Syntactic sugar for invoking a function and expanding an array for arguments.
 *
 * Common use case would be to use `Function.prototype.apply`.
 *
 *  ```js
 *  function f(x, y, z) {}
 *  var args = [1, 2, 3];
 *  f.apply(null, args);
 *  ```
 *
 * With `spread` this example can be re-written.
 *
 *  ```js
 *  spread(function(x, y, z) {})([1, 2, 3]);
 *  ```
 *
 * @param {Function} callback
 * @returns {Function}
 */


var spread = function spread(callback) {
  return function wrap(arr) {
    return callback.apply(null, arr);
  };
};

/**
 * Determines whether the payload is an error thrown by Axios
 *
 * @param {*} payload The value to test
 * @returns {boolean} True if the payload is an error thrown by Axios, otherwise false
 */


var isAxiosError = function isAxiosError(payload) {
  return typeof payload === 'object' && payload.isAxiosError === true;
};

var utils = utils$d;
var bind = bind$2;
var Axios = Axios_1;
var mergeConfig = mergeConfig$2;
var defaults = defaults_1;
/**
 * Create an instance of Axios
 *
 * @param {Object} defaultConfig The default config for the instance
 * @return {Axios} A new instance of Axios
 */

function createInstance(defaultConfig) {
  var context = new Axios(defaultConfig);
  var instance = bind(Axios.prototype.request, context); // Copy axios.prototype to instance

  utils.extend(instance, Axios.prototype, context); // Copy context to instance

  utils.extend(instance, context);
  return instance;
} // Create the default instance to be exported


var axios$1 = createInstance(defaults); // Expose Axios class to allow class inheritance

axios$1.Axios = Axios; // Factory for creating new instances

axios$1.create = function create(instanceConfig) {
  return createInstance(mergeConfig(axios$1.defaults, instanceConfig));
}; // Expose Cancel & CancelToken


axios$1.Cancel = Cancel_1;
axios$1.CancelToken = CancelToken_1;
axios$1.isCancel = isCancel$1; // Expose all/spread

axios$1.all = function all(promises) {
  return Promise.all(promises);
};

axios$1.spread = spread; // Expose isAxiosError

axios$1.isAxiosError = isAxiosError;
axios$2.exports = axios$1; // Allow use of default import syntax in TypeScript

axios$2.exports.default = axios$1;

var axios = axios$2.exports;

var ywfeUtils_umd = {exports: {}};

(function (module, exports) {
  !function (t, e) {
    e(exports) ;
  }(commonjsGlobal, function (t) {

    function e(t) {
      return null != t && "object" == typeof t && !0 === t["@@functional/placeholder"];
    }

    function n(t) {
      return function n(r) {
        return 0 === arguments.length || e(r) ? n : t.apply(this, arguments);
      };
    }

    function r(t) {
      return function r(o, i) {
        switch (arguments.length) {
          case 0:
            return r;

          case 1:
            return e(o) ? r : n(function (e) {
              return t(o, e);
            });

          default:
            return e(o) && e(i) ? r : e(o) ? n(function (e) {
              return t(e, i);
            }) : e(i) ? n(function (e) {
              return t(o, e);
            }) : t(o, i);
        }
      };
    }

    function o(t, e) {
      switch (t) {
        case 0:
          return function () {
            return e.apply(this, arguments);
          };

        case 1:
          return function (t) {
            return e.apply(this, arguments);
          };

        case 2:
          return function (t, n) {
            return e.apply(this, arguments);
          };

        case 3:
          return function (t, n, r) {
            return e.apply(this, arguments);
          };

        case 4:
          return function (t, n, r, o) {
            return e.apply(this, arguments);
          };

        case 5:
          return function (t, n, r, o, i) {
            return e.apply(this, arguments);
          };

        case 6:
          return function (t, n, r, o, i, u) {
            return e.apply(this, arguments);
          };

        case 7:
          return function (t, n, r, o, i, u, c) {
            return e.apply(this, arguments);
          };

        case 8:
          return function (t, n, r, o, i, u, c, a) {
            return e.apply(this, arguments);
          };

        case 9:
          return function (t, n, r, o, i, u, c, a, s) {
            return e.apply(this, arguments);
          };

        case 10:
          return function (t, n, r, o, i, u, c, a, s, f) {
            return e.apply(this, arguments);
          };

        default:
          throw new Error("First argument to _arity must be a non-negative integer no greater than ten");
      }
    }

    function i(t, n, r) {
      return function () {
        for (var u = [], c = 0, a = t, s = 0; s < n.length || c < arguments.length;) {
          var f;
          s < n.length && (!e(n[s]) || c >= arguments.length) ? f = n[s] : (f = arguments[c], c += 1), u[s] = f, e(f) || (a -= 1), s += 1;
        }

        return a <= 0 ? r.apply(this, u) : o(a, i(t, u, r));
      };
    }

    var u = r(function (t, e) {
      return 1 === t ? n(e) : o(t, i(t, [], e));
    });

    function c(t) {
      return function o(i, u, c) {
        switch (arguments.length) {
          case 0:
            return o;

          case 1:
            return e(i) ? o : r(function (e, n) {
              return t(i, e, n);
            });

          case 2:
            return e(i) && e(u) ? o : e(i) ? r(function (e, n) {
              return t(e, u, n);
            }) : e(u) ? r(function (e, n) {
              return t(i, e, n);
            }) : n(function (e) {
              return t(i, u, e);
            });

          default:
            return e(i) && e(u) && e(c) ? o : e(i) && e(u) ? r(function (e, n) {
              return t(e, n, c);
            }) : e(i) && e(c) ? r(function (e, n) {
              return t(e, u, n);
            }) : e(u) && e(c) ? r(function (e, n) {
              return t(i, e, n);
            }) : e(i) ? n(function (e) {
              return t(e, u, c);
            }) : e(u) ? n(function (e) {
              return t(i, e, c);
            }) : e(c) ? n(function (e) {
              return t(i, u, e);
            }) : t(i, u, c);
        }
      };
    }

    var a = Array.isArray || function (t) {
      return null != t && t.length >= 0 && "[object Array]" === Object.prototype.toString.call(t);
    };

    function s(t) {
      return null != t && "function" == typeof t["@@transducer/step"];
    }

    function f(t, e, n) {
      return function () {
        if (0 === arguments.length) return n();
        var r = Array.prototype.slice.call(arguments, 0),
            o = r.pop();

        if (!a(o)) {
          for (var i = 0; i < t.length;) {
            if ("function" == typeof o[t[i]]) return o[t[i]].apply(o, r);
            i += 1;
          }

          if (s(o)) {
            var u = e.apply(null, r);
            return u(o);
          }
        }

        return n.apply(this, arguments);
      };
    }

    var l = function () {
      return this.xf["@@transducer/init"]();
    },
        d = function (t) {
      return this.xf["@@transducer/result"](t);
    };

    function h(t, e) {
      for (var n = 0, r = e.length, o = Array(r); n < r;) o[n] = t(e[n]), n += 1;

      return o;
    }

    function p(t) {
      return "[object String]" === Object.prototype.toString.call(t);
    }

    var y = n(function (t) {
      return !!a(t) || !!t && "object" == typeof t && !p(t) && (1 === t.nodeType ? !!t.length : 0 === t.length || t.length > 0 && t.hasOwnProperty(0) && t.hasOwnProperty(t.length - 1));
    }),
        g = function () {
      function t(t) {
        this.f = t;
      }

      return t.prototype["@@transducer/init"] = function () {
        throw new Error("init not implemented on XWrap");
      }, t.prototype["@@transducer/result"] = function (t) {
        return t;
      }, t.prototype["@@transducer/step"] = function (t, e) {
        return this.f(t, e);
      }, t;
    }();

    var m = r(function (t, e) {
      return o(t.length, function () {
        return t.apply(e, arguments);
      });
    });

    function v(t, e, n) {
      for (var r = n.next(); !r.done;) {
        if ((e = t["@@transducer/step"](e, r.value)) && e["@@transducer/reduced"]) {
          e = e["@@transducer/value"];
          break;
        }

        r = n.next();
      }

      return t["@@transducer/result"](e);
    }

    function w(t, e, n, r) {
      return t["@@transducer/result"](n[r](m(t["@@transducer/step"], t), e));
    }

    var b = "undefined" != typeof Symbol ? Symbol.iterator : "@@iterator";

    function A(t, e, n) {
      if ("function" == typeof t && (t = function (t) {
        return new g(t);
      }(t)), y(n)) return function (t, e, n) {
        for (var r = 0, o = n.length; r < o;) {
          if ((e = t["@@transducer/step"](e, n[r])) && e["@@transducer/reduced"]) {
            e = e["@@transducer/value"];
            break;
          }

          r += 1;
        }

        return t["@@transducer/result"](e);
      }(t, e, n);
      if ("function" == typeof n["fantasy-land/reduce"]) return w(t, e, n, "fantasy-land/reduce");
      if (null != n[b]) return v(t, e, n[b]());
      if ("function" == typeof n.next) return v(t, e, n);
      if ("function" == typeof n.reduce) return w(t, e, n, "reduce");
      throw new TypeError("reduce: list must be array or iterable");
    }

    var j = function () {
      function t(t, e) {
        this.xf = e, this.f = t;
      }

      return t.prototype["@@transducer/init"] = l, t.prototype["@@transducer/result"] = d, t.prototype["@@transducer/step"] = function (t, e) {
        return this.xf["@@transducer/step"](t, this.f(e));
      }, t;
    }(),
        S = r(function (t, e) {
      return new j(t, e);
    });

    function O(t, e) {
      return Object.prototype.hasOwnProperty.call(e, t);
    }

    var E = Object.prototype.toString,
        x = function () {
      return "[object Arguments]" === E.call(arguments) ? function (t) {
        return "[object Arguments]" === E.call(t);
      } : function (t) {
        return O("callee", t);
      };
    }(),
        N = !{
      toString: null
    }.propertyIsEnumerable("toString"),
        $ = ["constructor", "valueOf", "isPrototypeOf", "toString", "propertyIsEnumerable", "hasOwnProperty", "toLocaleString"],
        M = function () {
      return arguments.propertyIsEnumerable("length");
    }(),
        T = function (t, e) {
      for (var n = 0; n < t.length;) {
        if (t[n] === e) return !0;
        n += 1;
      }

      return !1;
    },
        C = "function" != typeof Object.keys || M ? n(function (t) {
      if (Object(t) !== t) return [];
      var e,
          n,
          r = [],
          o = M && x(t);

      for (e in t) !O(e, t) || o && "length" === e || (r[r.length] = e);

      if (N) for (n = $.length - 1; n >= 0;) O(e = $[n], t) && !T(r, e) && (r[r.length] = e), n -= 1;
      return r;
    }) : n(function (t) {
      return Object(t) !== t ? [] : Object.keys(t);
    }),
        P = r(f(["fantasy-land/map", "map"], S, function (t, e) {
      switch (Object.prototype.toString.call(e)) {
        case "[object Function]":
          return u(e.length, function () {
            return t.call(this, e.apply(this, arguments));
          });

        case "[object Object]":
          return A(function (n, r) {
            return n[r] = t(e[r]), n;
          }, {}, C(e));

        default:
          return h(t, e);
      }
    })),
        k = Number.isInteger || function (t) {
      return t << 0 === t;
    },
        I = r(function (t, e) {
      var n = t < 0 ? e.length + t : t;
      return p(e) ? e.charAt(n) : e[n];
    }),
        D = r(function (t, e) {
      return t.map(function (t) {
        for (var n, r = e, o = 0; o < t.length;) {
          if (null == r) return;
          n = t[o], r = k(n) ? I(n, r) : r[n], o += 1;
        }

        return r;
      });
    }),
        F = r(function (t, e) {
      return D([t], e)[0];
    }),
        U = r(function (t, e) {
      return F([t], e);
    }),
        R = c(A),
        q = r(function (t, e) {
      return "function" == typeof e["fantasy-land/ap"] ? e["fantasy-land/ap"](t) : "function" == typeof t.ap ? t.ap(e) : "function" == typeof t ? function (n) {
        return t(n)(e(n));
      } : A(function (t, n) {
        return function (t, e) {
          var n;
          e = e || [];
          var r = (t = t || []).length,
              o = e.length,
              i = [];

          for (n = 0; n < r;) i[i.length] = t[n], n += 1;

          for (n = 0; n < o;) i[i.length] = e[n], n += 1;

          return i;
        }(t, P(n, e));
      }, [], t);
    }),
        _ = n(function (t) {
      for (var e = C(t), n = e.length, r = [], o = 0; o < n;) r[o] = t[e[o]], o += 1;

      return r;
    }),
        z = n(function (t) {
      return null == t;
    });

    function B(t) {
      var e = Object.prototype.toString.call(t);
      return "[object Function]" === e || "[object AsyncFunction]" === e || "[object GeneratorFunction]" === e || "[object AsyncGeneratorFunction]" === e;
    }

    var L = r(function (t, e) {
      var n = u(t, e);
      return u(t, function () {
        return A(q, P(n, arguments[0]), Array.prototype.slice.call(arguments, 1));
      });
    }),
        V = n(function (t) {
      return L(t.length, t);
    }),
        Z = n(function (t) {
      return u(t.length, t);
    });

    function W(t) {
      return function e(n) {
        for (var r, o, i, u = [], c = 0, a = n.length; c < a;) {
          if (y(n[c])) for (i = 0, o = (r = t ? e(n[c]) : n[c]).length; i < o;) u[u.length] = r[i], i += 1;else u[u.length] = n[c];
          c += 1;
        }

        return u;
      };
    }

    var Y = n(function (t) {
      return null === t ? "Null" : void 0 === t ? "Undefined" : Object.prototype.toString.call(t).slice(8, -1);
    }),
        H = V(n(function (t) {
      return !t;
    }));

    function Q(t, e) {
      return function () {
        return e.call(this, t.apply(this, arguments));
      };
    }

    function G(t, e) {
      return function () {
        var n = arguments.length;
        if (0 === n) return e();
        var r = arguments[n - 1];
        return a(r) || "function" != typeof r[t] ? e.apply(this, arguments) : r[t].apply(r, Array.prototype.slice.call(arguments, 0, n - 1));
      };
    }

    var X = c(G("slice", function (t, e, n) {
      return Array.prototype.slice.call(n, t, e);
    })),
        J = n(G("tail", X(1, 1 / 0)));

    function K() {
      if (0 === arguments.length) throw new Error("pipe requires at least one argument");
      return o(arguments[0].length, R(Q, arguments[0], J(arguments)));
    }

    function tt(t) {
      for (var e, n = []; !(e = t.next()).done;) n.push(e.value);

      return n;
    }

    function et(t, e, n) {
      for (var r = 0, o = n.length; r < o;) {
        if (t(e, n[r])) return !0;
        r += 1;
      }

      return !1;
    }

    var nt = "function" == typeof Object.is ? Object.is : function (t, e) {
      return t === e ? 0 !== t || 1 / t == 1 / e : t != t && e != e;
    };

    function rt(t, e, n, r) {
      var o = tt(t);

      function i(t, e) {
        return ot(t, e, n.slice(), r.slice());
      }

      return !et(function (t, e) {
        return !et(i, e, t);
      }, tt(e), o);
    }

    function ot(t, e, n, r) {
      if (nt(t, e)) return !0;
      var o,
          i,
          u = Y(t);
      if (u !== Y(e)) return !1;
      if (null == t || null == e) return !1;
      if ("function" == typeof t["fantasy-land/equals"] || "function" == typeof e["fantasy-land/equals"]) return "function" == typeof t["fantasy-land/equals"] && t["fantasy-land/equals"](e) && "function" == typeof e["fantasy-land/equals"] && e["fantasy-land/equals"](t);
      if ("function" == typeof t.equals || "function" == typeof e.equals) return "function" == typeof t.equals && t.equals(e) && "function" == typeof e.equals && e.equals(t);

      switch (u) {
        case "Arguments":
        case "Array":
        case "Object":
          if ("function" == typeof t.constructor && "Promise" === (o = t.constructor, null == (i = String(o).match(/^function (\w*)/)) ? "" : i[1])) return t === e;
          break;

        case "Boolean":
        case "Number":
        case "String":
          if (typeof t != typeof e || !nt(t.valueOf(), e.valueOf())) return !1;
          break;

        case "Date":
          if (!nt(t.valueOf(), e.valueOf())) return !1;
          break;

        case "Error":
          return t.name === e.name && t.message === e.message;

        case "RegExp":
          if (t.source !== e.source || t.global !== e.global || t.ignoreCase !== e.ignoreCase || t.multiline !== e.multiline || t.sticky !== e.sticky || t.unicode !== e.unicode) return !1;
      }

      for (var c = n.length - 1; c >= 0;) {
        if (n[c] === t) return r[c] === e;
        c -= 1;
      }

      switch (u) {
        case "Map":
          return t.size === e.size && rt(t.entries(), e.entries(), n.concat([t]), r.concat([e]));

        case "Set":
          return t.size === e.size && rt(t.values(), e.values(), n.concat([t]), r.concat([e]));

        case "Arguments":
        case "Array":
        case "Object":
        case "Boolean":
        case "Number":
        case "String":
        case "Date":
        case "Error":
        case "RegExp":
        case "Int8Array":
        case "Uint8Array":
        case "Uint8ClampedArray":
        case "Int16Array":
        case "Uint16Array":
        case "Int32Array":
        case "Uint32Array":
        case "Float32Array":
        case "Float64Array":
        case "ArrayBuffer":
          break;

        default:
          return !1;
      }

      var a = C(t);
      if (a.length !== C(e).length) return !1;
      var s = n.concat([t]),
          f = r.concat([e]);

      for (c = a.length - 1; c >= 0;) {
        var l = a[c];
        if (!O(l, e) || !ot(e[l], t[l], s, f)) return !1;
        c -= 1;
      }

      return !0;
    }

    var it = r(function (t, e) {
      return ot(t, e, [], []);
    });

    function ut(t, e) {
      return function (t, e, n) {
        var r, o;
        if ("function" == typeof t.indexOf) switch (typeof e) {
          case "number":
            if (0 === e) {
              for (r = 1 / e; n < t.length;) {
                if (0 === (o = t[n]) && 1 / o === r) return n;
                n += 1;
              }

              return -1;
            }

            if (e != e) {
              for (; n < t.length;) {
                if ("number" == typeof (o = t[n]) && o != o) return n;
                n += 1;
              }

              return -1;
            }

            return t.indexOf(e, n);

          case "string":
          case "boolean":
          case "function":
          case "undefined":
            return t.indexOf(e, n);

          case "object":
            if (null === e) return t.indexOf(e, n);
        }

        for (; n < t.length;) {
          if (it(t[n], e)) return n;
          n += 1;
        }

        return -1;
      }(e, t, 0) >= 0;
    }

    function ct(t) {
      return '"' + t.replace(/\\/g, "\\\\").replace(/[\b]/g, "\\b").replace(/\f/g, "\\f").replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/\t/g, "\\t").replace(/\v/g, "\\v").replace(/\0/g, "\\0").replace(/"/g, '\\"') + '"';
    }

    var at = function (t) {
      return (t < 10 ? "0" : "") + t;
    },
        st = "function" == typeof Date.prototype.toISOString ? function (t) {
      return t.toISOString();
    } : function (t) {
      return t.getUTCFullYear() + "-" + at(t.getUTCMonth() + 1) + "-" + at(t.getUTCDate()) + "T" + at(t.getUTCHours()) + ":" + at(t.getUTCMinutes()) + ":" + at(t.getUTCSeconds()) + "." + (t.getUTCMilliseconds() / 1e3).toFixed(3).slice(2, 5) + "Z";
    };

    function ft(t) {
      return "[object Object]" === Object.prototype.toString.call(t);
    }

    var lt = function () {
      function t(t, e) {
        this.xf = e, this.f = t;
      }

      return t.prototype["@@transducer/init"] = l, t.prototype["@@transducer/result"] = d, t.prototype["@@transducer/step"] = function (t, e) {
        return this.f(e) ? this.xf["@@transducer/step"](t, e) : t;
      }, t;
    }(),
        dt = r(f(["filter"], r(function (t, e) {
      return new lt(t, e);
    }), function (t, e) {
      return ft(e) ? A(function (n, r) {
        return t(e[r]) && (n[r] = e[r]), n;
      }, {}, C(e)) : function (t, e) {
        for (var n = 0, r = e.length, o = []; n < r;) t(e[n]) && (o[o.length] = e[n]), n += 1;

        return o;
      }(t, e);
    })),
        ht = r(function (t, e) {
      return dt((n = t, function () {
        return !n.apply(this, arguments);
      }), e);
      var n;
    });

    function pt(t, e) {
      var n = function (n) {
        var r = e.concat([t]);
        return ut(n, r) ? "<Circular>" : pt(n, r);
      },
          r = function (t, e) {
        return h(function (e) {
          return ct(e) + ": " + n(t[e]);
        }, e.slice().sort());
      };

      switch (Object.prototype.toString.call(t)) {
        case "[object Arguments]":
          return "(function() { return arguments; }(" + h(n, t).join(", ") + "))";

        case "[object Array]":
          return "[" + h(n, t).concat(r(t, ht(function (t) {
            return /^\d+$/.test(t);
          }, C(t)))).join(", ") + "]";

        case "[object Boolean]":
          return "object" == typeof t ? "new Boolean(" + n(t.valueOf()) + ")" : t.toString();

        case "[object Date]":
          return "new Date(" + (isNaN(t.valueOf()) ? n(NaN) : ct(st(t))) + ")";

        case "[object Null]":
          return "null";

        case "[object Number]":
          return "object" == typeof t ? "new Number(" + n(t.valueOf()) + ")" : 1 / t == -1 / 0 ? "-0" : t.toString(10);

        case "[object String]":
          return "object" == typeof t ? "new String(" + n(t.valueOf()) + ")" : ct(t);

        case "[object Undefined]":
          return "undefined";

        default:
          if ("function" == typeof t.toString) {
            var o = t.toString();
            if ("[object Object]" !== o) return o;
          }

          return "{" + r(t, C(t)).join(", ") + "}";
      }
    }

    var yt = n(function (t) {
      return pt(t, []);
    }),
        gt = r(function (t, e) {
      if (a(t)) {
        if (a(e)) return t.concat(e);
        throw new TypeError(yt(e) + " is not an array");
      }

      if (p(t)) {
        if (p(e)) return t + e;
        throw new TypeError(yt(e) + " is not a string");
      }

      if (null != t && B(t["fantasy-land/concat"])) return t["fantasy-land/concat"](e);
      if (null != t && B(t.concat)) return t.concat(e);
      throw new TypeError(yt(t) + ' does not have a method named "concat" or "fantasy-land/concat"');
    }),
        mt = n(function (t) {
      return null != t && "function" == typeof t["fantasy-land/empty"] ? t["fantasy-land/empty"]() : null != t && null != t.constructor && "function" == typeof t.constructor["fantasy-land/empty"] ? t.constructor["fantasy-land/empty"]() : null != t && "function" == typeof t.empty ? t.empty() : null != t && null != t.constructor && "function" == typeof t.constructor.empty ? t.constructor.empty() : a(t) ? [] : p(t) ? "" : ft(t) ? {} : x(t) ? function () {
        return arguments;
      }() : void 0;
    }),
        vt = function () {
      function t(t, e) {
        this.xf = e, this.f = t, this.found = !1;
      }

      return t.prototype["@@transducer/init"] = l, t.prototype["@@transducer/result"] = function (t) {
        return this.found || (t = this.xf["@@transducer/step"](t, void 0)), this.xf["@@transducer/result"](t);
      }, t.prototype["@@transducer/step"] = function (t, e) {
        var n;
        return this.f(e) && (this.found = !0, t = (n = this.xf["@@transducer/step"](t, e)) && n["@@transducer/reduced"] ? n : {
          "@@transducer/value": n,
          "@@transducer/reduced": !0
        }), t;
      }, t;
    }(),
        wt = r(f(["find"], r(function (t, e) {
      return new vt(t, e);
    }), function (t, e) {
      for (var n = 0, r = e.length; n < r;) {
        if (t(e[n])) return e[n];
        n += 1;
      }
    })),
        bt = n(W(!0)),
        At = n(function (t) {
      for (var e = {}, n = 0; n < t.length;) e[t[n][0]] = t[n][1], n += 1;

      return e;
    }),
        jt = r(function (t, e) {
      if (0 === t.length || z(e)) return !1;

      for (var n = e, r = 0; r < t.length;) {
        if (z(n) || !O(t[r], n)) return !1;
        n = n[t[r]], r += 1;
      }

      return !0;
    });

    var St = "function" == typeof Object.assign ? Object.assign : function (t) {
      if (null == t) throw new TypeError("Cannot convert undefined or null to object");

      for (var e = Object(t), n = 1, r = arguments.length; n < r;) {
        var o = arguments[n];
        if (null != o) for (var i in o) O(i, o) && (e[i] = o[i]);
        n += 1;
      }

      return e;
    },
        Ot = r(function (t, e) {
      return u(t + 1, function () {
        var n = arguments[t];
        if (null != n && B(n[e])) return n[e].apply(n, Array.prototype.slice.call(arguments, 0, t));
        throw new TypeError(yt(n) + ' does not have a method named "' + e + '"');
      });
    }),
        Et = r(function (t, e) {
      return null != e && e.constructor === t || e instanceof t;
    }),
        xt = n(function (t) {
      return null != t && it(t, mt(t));
    }),
        Nt = n(function (t) {
      return St.apply(null, [{}].concat(t));
    }),
        $t = r(function (t, e) {
      for (var n = {}, r = {}, o = 0, i = t.length; o < i;) r[t[o]] = 1, o += 1;

      for (var u in e) r.hasOwnProperty(u) || (n[u] = e[u]);

      return n;
    }),
        Mt = c(function (t, e, n) {
      return it(e, n[t]);
    }),
        Tt = c(function (t, e, n) {
      return n.replace(t, e);
    }),
        Ct = Ot(1, "split"),
        Pt = "\t\n\v\f\r   ᠎             　\u2028\u2029\ufeff",
        kt = n("function" == typeof String.prototype.trim && !Pt.trim() && "​".trim() ? function (t) {
      return t.trim();
    } : function (t) {
      var e = new RegExp("^[" + Pt + "][" + Pt + "]*"),
          n = new RegExp("[" + Pt + "][" + Pt + "]*$");
      return t.replace(e, "").replace(n, "");
    });

    const It = t => {
      if (z(t) || xt(t)) return t;

      switch (Y(t)) {
        case "String":
          return kt(t);

        case "Array":
          return dt(H(xt))(t);

        default:
          return t;
      }
    },
          Dt = (t, e) => xt(e) || z(e) ? [] : K(Ct(t), It)(e),
          Ft = {
      set: (t, e) => {
        "undefined" != typeof window && window.sessionStorage.setItem(t, e);
      },
      get: t => "undefined" != typeof window ? window.sessionStorage.getItem(t) : null,
      remove: t => {
        "undefined" != typeof window && window.sessionStorage.removeItem(t);
      },
      clear: () => {
        "undefined" != typeof window && window.sessionStorage.clear();
      }
    },
          Ut = {
      set: (t, e) => {
        "undefined" != typeof window && window.localStorage.setItem(t, e);
      },
      get: t => "undefined" != typeof window ? window.localStorage.getItem(t) : null,
      remove: t => {
        "undefined" != typeof window && window.localStorage.removeItem(t);
      },
      clear: () => {
        "undefined" != typeof window && window.localStorage.clear();
      }
    },
          Rt = {
      set: (t, e, n) => {
        const r = new Date();
        r.setTime(r.getTime() + n);
        const o = `expires=${r.toUTCString()}`;
        document.cookie = `${t}=${e};${o};path=/`;
      },
      get: t => {
        const e = `${t}=`,
              n = document.cookie.split(";");

        for (let t = 0; t < n.length; t += 1) {
          let r = n[t];

          for (; " " === r.charAt(0);) r = r.substring(1);

          if (-1 !== r.indexOf(e)) return r.substring(e.length, r.length);
        }
      }
    };

    function qt(t, e, n, r) {
      t.addEventListener(e, function r(o) {
        t.removeEventListener(e, r), n(o);
      }, r);
    }

    const _t = ["id", "type", "async", "defer", "crossOrigin", "integrity", "noModule"];

    const zt = t => {
      let e = t;
      return Et(String, t) && String(t).length >= 13 && (e = Number(t)), new Date(e) && "Invalid Date" !== String(new Date(e));
    },
          Bt = (t, e, n) => {
      const r = {
        reduce: Z((t, n, o) => {
          const i = t(n, o);
          return (t => jt([e], t))(o) && o[e] ? o[e].reduce(r.reduce(t), i) : i;
        })
      },
            o = (n, r) => t.value && r[t.key] && r[t.key] === t.value || !t.value && r[t.key] ? n.concat([$t([e], r)]) : n;

      switch (Y(n)) {
        case "Object":
          return r.reduce(o, [])(n);

        case "Array":
          return K(P(r.reduce(o, [])), bt)(n);

        default:
          return n;
      }
    },
          Lt = (t, e) => {
      let n = [],
          r = [],
          o = {};
      const i = wt(Mt("origion_url", `/${t[0]}`))(e);

      if (i) {
        if (n = [i.name], t.length > 1 && i.children && i.children.length) {
          const e = t.join("/");
          o = wt(Mt("origion_url", `/${e}`))(i.children);
        } else o = i.children && i.children.length ? i.children[0] : i;

        r = (null == o ? void 0 : o.name) ? [o.name] : [];
      }

      return {
        defaultOpenMenus: n,
        defaultSelectedMenus: r,
        defaultMenu: o
      };
    },
          Vt = t => {
      var e, n;
      let r = [],
          o = [],
          i = {};
      return t[0] && t[0].children && t[0].children.length ? (r = [t[0].name], o = [t[0].children[0].name], i = t[0].children[0]) : t[0] && (r = [null === (e = t[0]) || void 0 === e ? void 0 : e.name], o = [null === (n = t[0]) || void 0 === n ? void 0 : n.name], i = t[0]), {
        defaultOpenMenus: r,
        defaultSelectedMenus: o,
        defaultMenu: i
      };
    },
          Zt = () => {
      let t = "prod";
      const e = "prod" == String(process.env.REACT_APP_ENV);
      return t = "undefined" == typeof window ? (e ? "prod" : process.env.REACT_APP_ENV) || "prod" : window.localStorage.getItem("env") || (e ? "prod" : process.env.REACT_APP_ENV) || "prod", t;
    },
          Wt = t => {
      if (!t) return {};
      return K(Tt("?", ""), Ct("&"), P(t => Ct("=", t)), At)(t);
    };

    var Yt = Object.freeze({
      __proto__: null,
      parse: Wt,
      stringify: t => {
        if (xt(t)) return "";
        const e = Object.keys(t);
        let n = "";
        return e.map(e => {
          n += `&${e}=${t[e]}`;
        }), n;
      }
    });
    const Ht = {
      prod: "https://gateway.ywwl.com",
      dev: "https://dev-gateway.ywwl.com",
      test: "https://test-gateway.ywwl.com"
    };
    var Qt = 1e6,
        Gt = 1e6,
        Xt = "[big.js] ",
        Jt = Xt + "Invalid ",
        Kt = Jt + "decimal places",
        te = Jt + "rounding mode",
        ee = Xt + "Division by zero",
        ne = {},
        re = void 0,
        oe = /^-?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i;

    function ie(t, e, n, r) {
      var o = t.c,
          i = t.e + e + 1;

      if (i < o.length) {
        if (1 === n) r = o[i] >= 5;else if (2 === n) r = o[i] > 5 || 5 == o[i] && (r || i < 0 || o[i + 1] !== re || 1 & o[i - 1]);else if (3 === n) r = r || !!o[0];else if (r = !1, 0 !== n) throw Error(te);
        if (i < 1) o.length = 1, r ? (t.e = -e, o[0] = 1) : o[0] = t.e = 0;else {
          if (o.length = i--, r) for (; ++o[i] > 9;) o[i] = 0, i-- || (++t.e, o.unshift(1));

          for (i = o.length; !o[--i];) o.pop();
        }
      } else if (n < 0 || n > 3 || n !== ~~n) throw Error(te);

      return t;
    }

    function ue(t, e, n, r) {
      var o,
          i,
          u = t.constructor,
          c = !t.c[0];

      if (n !== re) {
        if (n !== ~~n || n < (3 == e) || n > Qt) throw Error(3 == e ? Jt + "precision" : Kt);

        for (n = r - (t = new u(t)).e, t.c.length > ++r && ie(t, n, u.RM), 2 == e && (r = t.e + n + 1); t.c.length < r;) t.c.push(0);
      }

      if (o = t.e, n = (i = t.c.join("")).length, 2 != e && (1 == e || 3 == e && r <= o || o <= u.NE || o >= u.PE)) i = i.charAt(0) + (n > 1 ? "." + i.slice(1) : "") + (o < 0 ? "e" : "e+") + o;else if (o < 0) {
        for (; ++o;) i = "0" + i;

        i = "0." + i;
      } else if (o > 0) {
        if (++o > n) for (o -= n; o--;) i += "0";else o < n && (i = i.slice(0, o) + "." + i.slice(o));
      } else n > 1 && (i = i.charAt(0) + "." + i.slice(1));
      return t.s < 0 && (!c || 4 == e) ? "-" + i : i;
    }

    ne.abs = function () {
      var t = new this.constructor(this);
      return t.s = 1, t;
    }, ne.cmp = function (t) {
      var e,
          n = this,
          r = n.c,
          o = (t = new n.constructor(t)).c,
          i = n.s,
          u = t.s,
          c = n.e,
          a = t.e;
      if (!r[0] || !o[0]) return r[0] ? i : o[0] ? -u : 0;
      if (i != u) return i;
      if (e = i < 0, c != a) return c > a ^ e ? 1 : -1;

      for (u = (c = r.length) < (a = o.length) ? c : a, i = -1; ++i < u;) if (r[i] != o[i]) return r[i] > o[i] ^ e ? 1 : -1;

      return c == a ? 0 : c > a ^ e ? 1 : -1;
    }, ne.div = function (t) {
      var e = this,
          n = e.constructor,
          r = e.c,
          o = (t = new n(t)).c,
          i = e.s == t.s ? 1 : -1,
          u = n.DP;
      if (u !== ~~u || u < 0 || u > Qt) throw Error(Kt);
      if (!o[0]) throw Error(ee);
      if (!r[0]) return new n(0 * i);
      var c,
          a,
          s,
          f,
          l,
          d = o.slice(),
          h = c = o.length,
          p = r.length,
          y = r.slice(0, c),
          g = y.length,
          m = t,
          v = m.c = [],
          w = 0,
          b = u + (m.e = e.e - t.e) + 1;

      for (m.s = i, i = b < 0 ? 0 : b, d.unshift(0); g++ < c;) y.push(0);

      do {
        for (s = 0; s < 10; s++) {
          if (c != (g = y.length)) f = c > g ? 1 : -1;else for (l = -1, f = 0; ++l < c;) if (o[l] != y[l]) {
            f = o[l] > y[l] ? 1 : -1;
            break;
          }
          if (!(f < 0)) break;

          for (a = g == c ? o : d; g;) {
            if (y[--g] < a[g]) {
              for (l = g; l && !y[--l];) y[l] = 9;

              --y[l], y[g] += 10;
            }

            y[g] -= a[g];
          }

          for (; !y[0];) y.shift();
        }

        v[w++] = f ? s : ++s, y[0] && f ? y[g] = r[h] || 0 : y = [r[h]];
      } while ((h++ < p || y[0] !== re) && i--);

      return v[0] || 1 == w || (v.shift(), m.e--), w > b && ie(m, u, n.RM, y[0] !== re), m;
    }, ne.eq = function (t) {
      return !this.cmp(t);
    }, ne.gt = function (t) {
      return this.cmp(t) > 0;
    }, ne.gte = function (t) {
      return this.cmp(t) > -1;
    }, ne.lt = function (t) {
      return this.cmp(t) < 0;
    }, ne.lte = function (t) {
      return this.cmp(t) < 1;
    }, ne.minus = ne.sub = function (t) {
      var e,
          n,
          r,
          o,
          i = this,
          u = i.constructor,
          c = i.s,
          a = (t = new u(t)).s;
      if (c != a) return t.s = -a, i.plus(t);
      var s = i.c.slice(),
          f = i.e,
          l = t.c,
          d = t.e;
      if (!s[0] || !l[0]) return l[0] ? (t.s = -a, t) : new u(s[0] ? i : 0);

      if (c = f - d) {
        for ((o = c < 0) ? (c = -c, r = s) : (d = f, r = l), r.reverse(), a = c; a--;) r.push(0);

        r.reverse();
      } else for (n = ((o = s.length < l.length) ? s : l).length, c = a = 0; a < n; a++) if (s[a] != l[a]) {
        o = s[a] < l[a];
        break;
      }

      if (o && (r = s, s = l, l = r, t.s = -t.s), (a = (n = l.length) - (e = s.length)) > 0) for (; a--;) s[e++] = 0;

      for (a = e; n > c;) {
        if (s[--n] < l[n]) {
          for (e = n; e && !s[--e];) s[e] = 9;

          --s[e], s[n] += 10;
        }

        s[n] -= l[n];
      }

      for (; 0 === s[--a];) s.pop();

      for (; 0 === s[0];) s.shift(), --d;

      return s[0] || (t.s = 1, s = [d = 0]), t.c = s, t.e = d, t;
    }, ne.mod = function (t) {
      var e,
          n = this,
          r = n.constructor,
          o = n.s,
          i = (t = new r(t)).s;
      if (!t.c[0]) throw Error(ee);
      return n.s = t.s = 1, e = 1 == t.cmp(n), n.s = o, t.s = i, e ? new r(n) : (o = r.DP, i = r.RM, r.DP = r.RM = 0, n = n.div(t), r.DP = o, r.RM = i, this.minus(n.times(t)));
    }, ne.plus = ne.add = function (t) {
      var e,
          n = this,
          r = n.constructor,
          o = n.s,
          i = (t = new r(t)).s;
      if (o != i) return t.s = -i, n.minus(t);
      var u = n.e,
          c = n.c,
          a = t.e,
          s = t.c;
      if (!c[0] || !s[0]) return s[0] ? t : new r(c[0] ? n : 0 * o);

      if (c = c.slice(), o = u - a) {
        for (o > 0 ? (a = u, e = s) : (o = -o, e = c), e.reverse(); o--;) e.push(0);

        e.reverse();
      }

      for (c.length - s.length < 0 && (e = s, s = c, c = e), o = s.length, i = 0; o; c[o] %= 10) i = (c[--o] = c[o] + s[o] + i) / 10 | 0;

      for (i && (c.unshift(i), ++a), o = c.length; 0 === c[--o];) c.pop();

      return t.c = c, t.e = a, t;
    }, ne.pow = function (t) {
      var e = this,
          n = new e.constructor(1),
          r = n,
          o = t < 0;
      if (t !== ~~t || t < -1e6 || t > Gt) throw Error(Jt + "exponent");

      for (o && (t = -t); 1 & t && (r = r.times(e)), t >>= 1;) e = e.times(e);

      return o ? n.div(r) : r;
    }, ne.round = function (t, e) {
      var n = this.constructor;
      if (t === re) t = 0;else if (t !== ~~t || t < -Qt || t > Qt) throw Error(Kt);
      return ie(new n(this), t, e === re ? n.RM : e);
    }, ne.sqrt = function () {
      var t,
          e,
          n,
          r = this,
          o = r.constructor,
          i = r.s,
          u = r.e,
          c = new o(.5);
      if (!r.c[0]) return new o(r);
      if (i < 0) throw Error(Xt + "No square root");
      0 === (i = Math.sqrt(r + "")) || i === 1 / 0 ? ((e = r.c.join("")).length + u & 1 || (e += "0"), u = ((u + 1) / 2 | 0) - (u < 0 || 1 & u), t = new o(((i = Math.sqrt(e)) == 1 / 0 ? "1e" : (i = i.toExponential()).slice(0, i.indexOf("e") + 1)) + u)) : t = new o(i), u = t.e + (o.DP += 4);

      do {
        n = t, t = c.times(n.plus(r.div(n)));
      } while (n.c.slice(0, u).join("") !== t.c.slice(0, u).join(""));

      return ie(t, o.DP -= 4, o.RM);
    }, ne.times = ne.mul = function (t) {
      var e,
          n = this,
          r = n.constructor,
          o = n.c,
          i = (t = new r(t)).c,
          u = o.length,
          c = i.length,
          a = n.e,
          s = t.e;
      if (t.s = n.s == t.s ? 1 : -1, !o[0] || !i[0]) return new r(0 * t.s);

      for (t.e = a + s, u < c && (e = o, o = i, i = e, s = u, u = c, c = s), e = new Array(s = u + c); s--;) e[s] = 0;

      for (a = c; a--;) {
        for (c = 0, s = u + a; s > a;) c = e[s] + i[a] * o[s - a - 1] + c, e[s--] = c % 10, c = c / 10 | 0;

        e[s] = (e[s] + c) % 10;
      }

      for (c ? ++t.e : e.shift(), a = e.length; !e[--a];) e.pop();

      return t.c = e, t;
    }, ne.toExponential = function (t) {
      return ue(this, 1, t, t);
    }, ne.toFixed = function (t) {
      return ue(this, 2, t, this.e + t);
    }, ne.toPrecision = function (t) {
      return ue(this, 3, t, t - 1);
    }, ne.toString = function () {
      return ue(this);
    }, ne.valueOf = ne.toJSON = function () {
      return ue(this, 4);
    };

    var ce = function t() {
      function e(n) {
        var r = this;
        if (!(r instanceof e)) return n === re ? t() : new e(n);
        n instanceof e ? (r.s = n.s, r.e = n.e, r.c = n.c.slice()) : function (t, e) {
          var n, r, o;
          if (0 === e && 1 / e < 0) e = "-0";else if (!oe.test(e += "")) throw Error(Jt + "number");
          t.s = "-" == e.charAt(0) ? (e = e.slice(1), -1) : 1, (n = e.indexOf(".")) > -1 && (e = e.replace(".", ""));
          (r = e.search(/e/i)) > 0 ? (n < 0 && (n = r), n += +e.slice(r + 1), e = e.substring(0, r)) : n < 0 && (n = e.length);

          for (o = e.length, r = 0; r < o && "0" == e.charAt(r);) ++r;

          if (r == o) t.c = [t.e = 0];else {
            for (; o > 0 && "0" == e.charAt(--o););

            for (t.e = n - r - 1, t.c = [], n = 0; r <= o;) t.c[n++] = +e.charAt(r++);
          }
        }(r, n), r.constructor = e;
      }

      return e.prototype = ne, e.DP = 20, e.RM = 1, e.NE = -7, e.PE = 21, e.version = "5.2.2", e;
    }();

    const ae = (t, e) => {
      const n = (t = t.toString()).indexOf(".");
      return t = -1 !== n ? t.substring(0, e + n + 1) : t.substring(0), Number(parseFloat(t).toFixed(e));
    },
          se = t => (e, n) => {
      if (xt(e) || z(e)) return e;
      if (isNaN(Number(e))) return NaN;
      const r = Number(new ce(Number(e)).mul(t));
      if (z(null == n ? void 0 : n.decimalNumber) && z(null == n ? void 0 : n.fn)) return r;
      if (!z(null == n ? void 0 : n.decimalNumber) && z(null == n ? void 0 : n.fn)) return Number(r.toFixed(null == n ? void 0 : n.decimalNumber));

      if (!z(null == n ? void 0 : n.decimalNumber) && !z(null == n ? void 0 : n.fn)) {
        if ("toFixed" === (null == n ? void 0 : n.fn)) return Number(r.toFixed(null == n ? void 0 : n.decimalNumber));
        if ("floor" === (null == n ? void 0 : n.fn)) return ae(r, null == n ? void 0 : n.decimalNumber);
      }
    },
          fe = t => (e, n) => {
      const r = (null == n ? void 0 : n.decimalNumber) || 2,
            o = (null == n ? void 0 : n.fn) || "toFixed";
      if (xt(e) || z(e)) return e;
      if (isNaN(Number(e))) return NaN;
      const i = new ce(Number(e)).div(t);
      return "toFixed" === o ? Number(i.toFixed(r)) : "floor" === o ? ae(Number(i), r) : e;
    },
          le = t => {
      const e = Object.prototype.toString.call(t),
            n = /^\[object (.*)\]$/.exec(e);
      return null !== n ? n[1].toLowerCase() : null;
    },
          de = t => "string" == typeof t ? kt(t) : ("array" !== le(t) && "object" !== le(t) || (Array.isArray(t) && t.forEach(t => {
      de(t);
    }), null === typeof t) || Object.keys(t).map(e => {
      const n = t[e];
      "string" == typeof n && (t[e] = kt(n)), "object" !== le(n) && "array" !== le(n) || de(n);
    }), t);

    var he,
        pe = new Uint8Array(16);

    function ye() {
      if (!he && !(he = "undefined" != typeof crypto && crypto.getRandomValues && crypto.getRandomValues.bind(crypto) || "undefined" != typeof msCrypto && "function" == typeof msCrypto.getRandomValues && msCrypto.getRandomValues.bind(msCrypto))) throw new Error("crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported");
      return he(pe);
    }

    var ge = /^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i;

    function me(t) {
      return "string" == typeof t && ge.test(t);
    }

    for (var ve = [], we = 0; we < 256; ++we) ve.push((we + 256).toString(16).substr(1));

    function be(t, e, n) {
      var r = (t = t || {}).random || (t.rng || ye)();

      if (r[6] = 15 & r[6] | 64, r[8] = 63 & r[8] | 128, e) {
        n = n || 0;

        for (var o = 0; o < 16; ++o) e[n + o] = r[o];

        return e;
      }

      return function (t) {
        var e = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : 0,
            n = (ve[t[e + 0]] + ve[t[e + 1]] + ve[t[e + 2]] + ve[t[e + 3]] + "-" + ve[t[e + 4]] + ve[t[e + 5]] + "-" + ve[t[e + 6]] + ve[t[e + 7]] + "-" + ve[t[e + 8]] + ve[t[e + 9]] + "-" + ve[t[e + 10]] + ve[t[e + 11]] + ve[t[e + 12]] + ve[t[e + 13]] + ve[t[e + 14]] + ve[t[e + 15]]).toLowerCase();
        if (!me(n)) throw TypeError("Stringified UUID is invalid");
        return n;
      }(r);
    }

    const Ae = "input is invalid type",
          je = "0123456789abcdef".split(""),
          Se = [128, 32768, 8388608, -2147483648];
    let Oe,
        Ee = [];
    const xe = new ArrayBuffer(68);
    Oe = new Uint8Array(xe), Ee = new Uint32Array(xe);

    function Ne() {
      Ee[0] = Ee[16] = Ee[1] = Ee[2] = Ee[3] = Ee[4] = Ee[5] = Ee[6] = Ee[7] = Ee[8] = Ee[9] = Ee[10] = Ee[11] = Ee[12] = Ee[13] = Ee[14] = Ee[15] = 0, this.blocks = Ee, this.buffer8 = Oe, this.h0 = this.h1 = this.h2 = this.h3 = this.start = this.bytes = this.hBytes = 0, this.finalized = this.hashed = !1, this.first = !0;
    }

    Ne.prototype.update = function (t) {
      if (this.finalized) return;
      let e;
      const n = typeof t;

      if ("string" !== n) {
        if ("object" !== n) throw Ae;
        if (null === t) throw Ae;
        if (t.constructor === ArrayBuffer) t = new Uint8Array(t);else if (!Array.isArray(t) && !ArrayBuffer.isView(t)) throw Ae;
        e = !0;
      }

      let r,
          o,
          i = 0,
          u = t.length,
          c = this.blocks,
          a = this.buffer8;

      for (; i < u;) {
        if (this.hashed && (this.hashed = !1, c[0] = c[16], c[16] = c[1] = c[2] = c[3] = c[4] = c[5] = c[6] = c[7] = c[8] = c[9] = c[10] = c[11] = c[12] = c[13] = c[14] = c[15] = 0), e) for (o = this.start; i < u && o < 64; ++i) a[o++] = t[i];else for (o = this.start; i < u && o < 64; ++i) r = t.charCodeAt(i), r < 128 ? a[o++] = r : r < 2048 ? (a[o++] = 192 | r >> 6, a[o++] = 128 | 63 & r) : r < 55296 || r >= 57344 ? (a[o++] = 224 | r >> 12, a[o++] = 128 | r >> 6 & 63, a[o++] = 128 | 63 & r) : (r = 65536 + ((1023 & r) << 10 | 1023 & t.charCodeAt(++i)), a[o++] = 240 | r >> 18, a[o++] = 128 | r >> 12 & 63, a[o++] = 128 | r >> 6 & 63, a[o++] = 128 | 63 & r);
        this.lastByteIndex = o, this.bytes += o - this.start, o >= 64 ? (this.start = o - 64, this.hash(), this.hashed = !0) : this.start = o;
      }

      return this.bytes > 4294967295 && (this.hBytes += this.bytes / 4294967296 << 0, this.bytes = this.bytes % 4294967296), this;
    }, Ne.prototype.finalize = function () {
      if (this.finalized) return;
      this.finalized = !0;
      const t = this.blocks,
            e = this.lastByteIndex;
      t[e >> 2] |= Se[3 & e], e >= 56 && (this.hashed || this.hash(), t[0] = t[16], t[16] = t[1] = t[2] = t[3] = t[4] = t[5] = t[6] = t[7] = t[8] = t[9] = t[10] = t[11] = t[12] = t[13] = t[14] = t[15] = 0), t[14] = this.bytes << 3, t[15] = this.hBytes << 3 | this.bytes >>> 29, this.hash();
    }, Ne.prototype.hash = function () {
      let t,
          e,
          n,
          r,
          o,
          i,
          u = this.blocks;
      this.first ? (t = u[0] - 680876937, t = (t << 7 | t >>> 25) - 271733879 << 0, r = (-1732584194 ^ 2004318071 & t) + u[1] - 117830708, r = (r << 12 | r >>> 20) + t << 0, n = (-271733879 ^ r & (-271733879 ^ t)) + u[2] - 1126478375, n = (n << 17 | n >>> 15) + r << 0, e = (t ^ n & (r ^ t)) + u[3] - 1316259209, e = (e << 22 | e >>> 10) + n << 0) : (t = this.h0, e = this.h1, n = this.h2, r = this.h3, t += (r ^ e & (n ^ r)) + u[0] - 680876936, t = (t << 7 | t >>> 25) + e << 0, r += (n ^ t & (e ^ n)) + u[1] - 389564586, r = (r << 12 | r >>> 20) + t << 0, n += (e ^ r & (t ^ e)) + u[2] + 606105819, n = (n << 17 | n >>> 15) + r << 0, e += (t ^ n & (r ^ t)) + u[3] - 1044525330, e = (e << 22 | e >>> 10) + n << 0), t += (r ^ e & (n ^ r)) + u[4] - 176418897, t = (t << 7 | t >>> 25) + e << 0, r += (n ^ t & (e ^ n)) + u[5] + 1200080426, r = (r << 12 | r >>> 20) + t << 0, n += (e ^ r & (t ^ e)) + u[6] - 1473231341, n = (n << 17 | n >>> 15) + r << 0, e += (t ^ n & (r ^ t)) + u[7] - 45705983, e = (e << 22 | e >>> 10) + n << 0, t += (r ^ e & (n ^ r)) + u[8] + 1770035416, t = (t << 7 | t >>> 25) + e << 0, r += (n ^ t & (e ^ n)) + u[9] - 1958414417, r = (r << 12 | r >>> 20) + t << 0, n += (e ^ r & (t ^ e)) + u[10] - 42063, n = (n << 17 | n >>> 15) + r << 0, e += (t ^ n & (r ^ t)) + u[11] - 1990404162, e = (e << 22 | e >>> 10) + n << 0, t += (r ^ e & (n ^ r)) + u[12] + 1804603682, t = (t << 7 | t >>> 25) + e << 0, r += (n ^ t & (e ^ n)) + u[13] - 40341101, r = (r << 12 | r >>> 20) + t << 0, n += (e ^ r & (t ^ e)) + u[14] - 1502002290, n = (n << 17 | n >>> 15) + r << 0, e += (t ^ n & (r ^ t)) + u[15] + 1236535329, e = (e << 22 | e >>> 10) + n << 0, t += (n ^ r & (e ^ n)) + u[1] - 165796510, t = (t << 5 | t >>> 27) + e << 0, r += (e ^ n & (t ^ e)) + u[6] - 1069501632, r = (r << 9 | r >>> 23) + t << 0, n += (t ^ e & (r ^ t)) + u[11] + 643717713, n = (n << 14 | n >>> 18) + r << 0, e += (r ^ t & (n ^ r)) + u[0] - 373897302, e = (e << 20 | e >>> 12) + n << 0, t += (n ^ r & (e ^ n)) + u[5] - 701558691, t = (t << 5 | t >>> 27) + e << 0, r += (e ^ n & (t ^ e)) + u[10] + 38016083, r = (r << 9 | r >>> 23) + t << 0, n += (t ^ e & (r ^ t)) + u[15] - 660478335, n = (n << 14 | n >>> 18) + r << 0, e += (r ^ t & (n ^ r)) + u[4] - 405537848, e = (e << 20 | e >>> 12) + n << 0, t += (n ^ r & (e ^ n)) + u[9] + 568446438, t = (t << 5 | t >>> 27) + e << 0, r += (e ^ n & (t ^ e)) + u[14] - 1019803690, r = (r << 9 | r >>> 23) + t << 0, n += (t ^ e & (r ^ t)) + u[3] - 187363961, n = (n << 14 | n >>> 18) + r << 0, e += (r ^ t & (n ^ r)) + u[8] + 1163531501, e = (e << 20 | e >>> 12) + n << 0, t += (n ^ r & (e ^ n)) + u[13] - 1444681467, t = (t << 5 | t >>> 27) + e << 0, r += (e ^ n & (t ^ e)) + u[2] - 51403784, r = (r << 9 | r >>> 23) + t << 0, n += (t ^ e & (r ^ t)) + u[7] + 1735328473, n = (n << 14 | n >>> 18) + r << 0, e += (r ^ t & (n ^ r)) + u[12] - 1926607734, e = (e << 20 | e >>> 12) + n << 0, o = e ^ n, t += (o ^ r) + u[5] - 378558, t = (t << 4 | t >>> 28) + e << 0, r += (o ^ t) + u[8] - 2022574463, r = (r << 11 | r >>> 21) + t << 0, i = r ^ t, n += (i ^ e) + u[11] + 1839030562, n = (n << 16 | n >>> 16) + r << 0, e += (i ^ n) + u[14] - 35309556, e = (e << 23 | e >>> 9) + n << 0, o = e ^ n, t += (o ^ r) + u[1] - 1530992060, t = (t << 4 | t >>> 28) + e << 0, r += (o ^ t) + u[4] + 1272893353, r = (r << 11 | r >>> 21) + t << 0, i = r ^ t, n += (i ^ e) + u[7] - 155497632, n = (n << 16 | n >>> 16) + r << 0, e += (i ^ n) + u[10] - 1094730640, e = (e << 23 | e >>> 9) + n << 0, o = e ^ n, t += (o ^ r) + u[13] + 681279174, t = (t << 4 | t >>> 28) + e << 0, r += (o ^ t) + u[0] - 358537222, r = (r << 11 | r >>> 21) + t << 0, i = r ^ t, n += (i ^ e) + u[3] - 722521979, n = (n << 16 | n >>> 16) + r << 0, e += (i ^ n) + u[6] + 76029189, e = (e << 23 | e >>> 9) + n << 0, o = e ^ n, t += (o ^ r) + u[9] - 640364487, t = (t << 4 | t >>> 28) + e << 0, r += (o ^ t) + u[12] - 421815835, r = (r << 11 | r >>> 21) + t << 0, i = r ^ t, n += (i ^ e) + u[15] + 530742520, n = (n << 16 | n >>> 16) + r << 0, e += (i ^ n) + u[2] - 995338651, e = (e << 23 | e >>> 9) + n << 0, t += (n ^ (e | ~r)) + u[0] - 198630844, t = (t << 6 | t >>> 26) + e << 0, r += (e ^ (t | ~n)) + u[7] + 1126891415, r = (r << 10 | r >>> 22) + t << 0, n += (t ^ (r | ~e)) + u[14] - 1416354905, n = (n << 15 | n >>> 17) + r << 0, e += (r ^ (n | ~t)) + u[5] - 57434055, e = (e << 21 | e >>> 11) + n << 0, t += (n ^ (e | ~r)) + u[12] + 1700485571, t = (t << 6 | t >>> 26) + e << 0, r += (e ^ (t | ~n)) + u[3] - 1894986606, r = (r << 10 | r >>> 22) + t << 0, n += (t ^ (r | ~e)) + u[10] - 1051523, n = (n << 15 | n >>> 17) + r << 0, e += (r ^ (n | ~t)) + u[1] - 2054922799, e = (e << 21 | e >>> 11) + n << 0, t += (n ^ (e | ~r)) + u[8] + 1873313359, t = (t << 6 | t >>> 26) + e << 0, r += (e ^ (t | ~n)) + u[15] - 30611744, r = (r << 10 | r >>> 22) + t << 0, n += (t ^ (r | ~e)) + u[6] - 1560198380, n = (n << 15 | n >>> 17) + r << 0, e += (r ^ (n | ~t)) + u[13] + 1309151649, e = (e << 21 | e >>> 11) + n << 0, t += (n ^ (e | ~r)) + u[4] - 145523070, t = (t << 6 | t >>> 26) + e << 0, r += (e ^ (t | ~n)) + u[11] - 1120210379, r = (r << 10 | r >>> 22) + t << 0, n += (t ^ (r | ~e)) + u[2] + 718787259, n = (n << 15 | n >>> 17) + r << 0, e += (r ^ (n | ~t)) + u[9] - 343485551, e = (e << 21 | e >>> 11) + n << 0, this.first ? (this.h0 = t + 1732584193 << 0, this.h1 = e - 271733879 << 0, this.h2 = n - 1732584194 << 0, this.h3 = r + 271733878 << 0, this.first = !1) : (this.h0 = this.h0 + t << 0, this.h1 = this.h1 + e << 0, this.h2 = this.h2 + n << 0, this.h3 = this.h3 + r << 0);
    }, Ne.prototype.hex = function () {
      this.finalize();
      let t = this.h0,
          e = this.h1,
          n = this.h2,
          r = this.h3;
      return je[t >> 4 & 15] + je[15 & t] + je[t >> 12 & 15] + je[t >> 8 & 15] + je[t >> 20 & 15] + je[t >> 16 & 15] + je[t >> 28 & 15] + je[t >> 24 & 15] + je[e >> 4 & 15] + je[15 & e] + je[e >> 12 & 15] + je[e >> 8 & 15] + je[e >> 20 & 15] + je[e >> 16 & 15] + je[e >> 28 & 15] + je[e >> 24 & 15] + je[n >> 4 & 15] + je[15 & n] + je[n >> 12 & 15] + je[n >> 8 & 15] + je[n >> 20 & 15] + je[n >> 16 & 15] + je[n >> 28 & 15] + je[n >> 24 & 15] + je[r >> 4 & 15] + je[15 & r] + je[r >> 12 & 15] + je[r >> 8 & 15] + je[r >> 20 & 15] + je[r >> 16 & 15] + je[r >> 28 & 15] + je[r >> 24 & 15];
    };

    var $e = t => new Ne().update(t).hex();

    function Me(t) {
      const e = typeof t;
      return null != t && ("object" === e || "function" === e);
    }

    function Te(t, e, n) {
      if ("undefined" == typeof window) return;
      let r,
          o,
          i,
          u,
          c,
          a,
          s = 0,
          f = !1,
          l = !1,
          d = !0;
      const h = !e && 0 !== e && "function" == typeof requestAnimationFrame;
      if ("function" != typeof t) throw new TypeError("Expected a function");

      function p(e) {
        const n = r,
              i = o;
        return r = o = void 0, s = e, u = t.apply(i, n), u;
      }

      function y(t, e) {
        return h ? (cancelAnimationFrame(c), requestAnimationFrame(t)) : setTimeout(t, e);
      }

      function g(t) {
        const n = t - a;
        return void 0 === a || n >= e || n < 0 || l && t - s >= i;
      }

      function m() {
        const t = Date.now();
        if (g(t)) return v(t);
        c = y(m, function (t) {
          const n = t - s,
                r = e - (t - a);
          return l ? Math.min(r, i - n) : r;
        }(t));
      }

      function v(t) {
        return c = void 0, d && r ? p(t) : (r = o = void 0, u);
      }

      function w(...t) {
        const n = Date.now(),
              i = g(n);

        if (r = t, o = this, a = n, i) {
          if (void 0 === c) return function (t) {
            return s = t, c = y(m, e), f ? p(t) : u;
          }(a);
          if (l) return c = y(m, e), p(a);
        }

        return void 0 === c && (c = y(m, e)), u;
      }

      return e = +e || 0, Me(n) && (f = !!n.leading, l = "maxWait" in n, i = l ? Math.max(+n.maxWait || 0, e) : i, d = "trailing" in n ? !!n.trailing : d), w.cancel = function () {
        void 0 !== c && function (t) {
          if (h) return cancelAnimationFrame(t);
          clearTimeout(t);
        }(c), s = 0, r = a = o = c = void 0;
      }, w.flush = function () {
        return void 0 === c ? u : v(Date.now());
      }, w.pending = function () {
        return void 0 !== c;
      }, w;
    }

    t.YC = Rt, t.YL = Ut, t.YR = {
      email: /\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*/,
      phone: /^1[3|4|5|6|7|8][0-9]{9}$/,
      fixedPhone: /(^0\d{2,3}-\d{7,8}$)|(^1[3|4|5|6|7|8][0-9]{9}$)/,
      qq: /[1-9][0-9]{4,}/,
      zipcode: /[1-9]\d{5}(?!\d)/,
      IDCard: /^\d{17}[\d|X|x]|\d{15}$/,
      chinese: /^[\u0391-\uFFE5]+$/,
      chineseNumberLine: /^[\u4E00-\u9FA5A-Za-z0-9_]+$/,
      chineseNumberNoLine: /^[\u4E00-\u9FA5A-Za-z0-9]+$/,
      integerZ: /^[1-9]\d*$/,
      integerF: /^-[1-9]\d*$/,
      number: /^\d+(\.\d+)?$/,
      numberNoMoreThan1: /^\-?([0-9](\d+)?(\.\d{1,1})?$)|(^0$)|(^\d\.\d{1,1})$/,
      numberNoMoreThan2: /^\-?([0-9](\d+)?(\.\d{1,2})?$)|(^0$)|(^\d\.\d{1,2})$/,
      numberNoMoreThan3: /^\-?([0-9](\d+)?(\.\d{1,3})?$)|(^0$)|(^\d\.\d{1,3})$/,
      numberNoMoreThan4: /^\-?([0-9](\d+)?(\.\d{1,4})?$)|(^0$)|(^\d\.\d{1,4})$/,
      greaterZero1: /^(0|[1-9]\d*)(\.\d{1,1})?$/,
      greaterZero2: /^(0|[1-9]\d*)(\.\d{1,2})?$/,
      greaterZero3: /^(0|[1-9]\d*)(\.\d{1,3})?$/,
      greaterZero4: /^(0|[1-9]\d*)(\.\d{1,4})?$/,
      zeroTo100: /^((\d|[1-9]\d)(\.\d{1,2})?$)|(^100|100.0|100.00$)$/,
      zeroTo1000: /^((\d|[1-9]{1,2}\d)(\.\d{1,2})?$)|(^1000|1000.0|1000.00$)$/
    }, t.YS = Ft, t.debounce = Te, t.expandMultiple = (t, e, n) => se(t)(e, n), t.exportExcel = (t, e = {}, n = !1) => {
      const r = Zt();
      let o;
      "undefined" != typeof window && (o = window.localStorage.getItem("token"));
      const i = Object.assign({}, e, {
        token: o
      });
      /^https.*/.test(t) || (t = t.replace("http", "https"));
      const u = `${n ? Ht[r] : t}${t}?${(t => {
        const e = [];
        return Object.keys(t).forEach(n => {
          xt(t[n]) || z(t[n]) || e.push(`${n}=${t[n]}`);
        }), e.join("&");
      })(i)}`;
      console.log("YWFE下载地址=>", u);
      const c = `alink_${new Date().getTime()}`,
            a = document.createElement("a");
      a.setAttribute("href", u), a.setAttribute("target", "_blank"), a.setAttribute("id", c), document.getElementById(c) || document.body.appendChild(a), a.click(), setTimeout(() => {
        document.body.removeChild(a);
      }, 0);
    }, t.fenToyuan = (t, e) => fe(100)(t, e), t.gTokg = (t, e) => fe(1e3)(t, e), t.getBiteLen = t => {
      if ("string" != typeof t) return 0;
      let e = 0;

      for (let n = 0; n < t.length; n++) t.charCodeAt(n) > 127 || 94 === t.charCodeAt(n) ? e += 2 : e += 1;

      return e;
    }, t.getEnv = Zt, t.getHost = (t, e) => {
      const n = window.configs ? window.configs : {};
      let r = Zt();
      return {
        basePath: n[t] ? n[t][r].API_BASE_URL + "" + ("mock" === r ? "/" + e : "") : "",
        loginPath: n.AUTH ? n.AUTH[r].APPLICATION_URL : ""
      };
    }, t.getMD5 = t => xt(t) || z(t) ? t : Et(String, t) ? $e(t) : t, t.getQueries = t => {
      let e = t || window.location.search;
      return e = e.replace("?", ""), Wt(e) || {};
    }, t.getQuery = (t, e) => {
      const n = new RegExp(`(^|&)${t}=([^&]*)(&|$)`, "i").exec((e || window.location.search).substr(1));
      return null != n && unescape(n[2]) || "";
    }, t.getQueryOfNextPageContext = t => {
      if (!t) return {};
      const {
        pathname: e = "",
        asPath: n = "",
        query: r
      } = t,
            o = K(Ct("/"), dt(t => /\[\w+\]/.test(t)), P(t => Tt("]", "", Tt("[", "", t))))(e),
            i = K(Ct("#"), X(0, 1))(n) || [],
            u = i.length ? K(Ct("/"), dt(t => "" !== t))(i[0]) : [],
            c = o.map((t, e) => ({
        [`${t}`]: u[e]
      }));
      let a = {};
      return o.length ? a = Nt(c) || {} : a.path = u[0] || "desktop", Object.assign(Object.assign({}, r), a);
    }, t.getRoutes = (t, e, n, r) => {
      if (xt(t) || xt(e)) return {
        menus: [],
        defaultSelectedMenus: [],
        defaultOpenMenus: [],
        defaultMenu: {},
        permissions: []
      };
      let o;
      o = "/" !== r && "/undefined" !== r && "/null" !== r ? Dt("/", r) : [];
      let i = [],
          u = [],
          c = {};

      const a = t => {
        const r = e[t.url];
        if (!r) return {};
        const o = 0 === t.url.indexOf("/") ? t.url || "" : `/${t.url}`,
              a = {
          path: o,
          param: r.param || "",
          url: r.url,
          name: t.resourceId,
          meta: {
            title: t.name,
            icon: r.icon
          },
          component: r.component,
          hidden: r.hidden,
          origion_url: o
        };
        return ((null == n ? void 0 : n.primaryDefaultMenu) && t.url === (null == n ? void 0 : n.primaryDefaultMenu) || (null == n ? void 0 : n.secondaryDefaultMenu) && t.url === (null == n ? void 0 : n.secondaryDefaultMenu)) && (i = [t.resourceParentId], u = [t.resourceId], c = a), a;
      },
            s = [];

      let f = [];

      if (t.map(t => {
        const n = [],
              r = e[t.url],
              o = Bt({
          key: "resourceType",
          value: "BUTTON"
        }, "childMenus", t);

        if (o && o.length) {
          const t = K(P(U("url")))(o);
          f = gt(f, t);
        }

        if (t.childMenus && t.childMenus.length) {
          Bt({
            key: "resourceId"
          }, "childMenus", t.childMenus).map(t => {
            if (t) {
              const e = a(t);
              e && e.name && n.push(e);
            }
          });
        }

        const i = a(t);
        r && s.push(Object.assign(Object.assign({}, i), {
          children: n
        }));
      }), o.length && s.length) {
        const t = Lt(o, s);
        u = t.defaultSelectedMenus, i = t.defaultOpenMenus, c = t.defaultMenu;
      } else if (!u.length || !i.length || !c) {
        const t = Vt(s);
        u = t.defaultSelectedMenus, i = t.defaultOpenMenus, c = t.defaultMenu;
      }

      return {
        menus: s,
        defaultSelectedMenus: u,
        defaultOpenMenus: i,
        defaultMenu: c,
        permissions: f
      };
    }, t.humpToLine = function (t) {
      return "string" != typeof t ? t : t.replace(/([A-Z])/g, "_$1").toLowerCase();
    }, t.isChinaMobile = t => /^((\+86)|(86)|(086))?(13[0-9]|15[0-9]|166|17[0-9]|18[0-9]|14[0-9]|19[0-9])[0-9]{8}$/.test(String(t)), t.isDate = zt, t.isURL = t => /^((?:(?:https?|ftp):|)\/\/)(?:\S+(?::\S*)?@)?(?:(?!(?:10|127)(?:\.\d{1,3}){3})(?!(?:169\.254|192\.168)(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)(?:\.(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)*(?:\.(?:[a-z\u00a1-\uffff]{2,}))\.?)(?::\d{2,5})?(?:[/?#]\S*)?$/i.test(String(t)), t.kgTog = (t, e) => se(1e3)(t, e), t.lineToHump = function (t) {
      return "string" != typeof t ? t : t.replace(/\_(\w)/g, function (t, e) {
        return e.toUpperCase();
      });
    }, t.loadScript = function (t, e, n) {
      return new Promise((r, o) => {
        const i = document.createElement("script");
        var u, c;
        i.id = e, i.readyState ? (c = () => r(i), (u = i).onreadystatechange = function () {
          "loaded" !== u.readyState && "complete" !== u.readyState || (u.onreadystatechange = null, c());
        }) : function (t, e, n) {
          qt(t, "load", e), qt(t, "error", n);
        }(i, () => r(i), () => {
          o(), document.removeChild(document.getElementById(e));
        }), n && _t.forEach(t => {
          if (t in n) {
            const e = n[t];
            "string" == typeof e ? i.setAttribute(t, e) : "boolean" == typeof e && (i[t] = e);
          }
        }), i.src = t.js, document.body.appendChild(i);
      });
    }, t.maxSubstrWord = (t, e = 5, n = !0) => "string" == typeof t ? n ? `${t.substr(0, e)}...` : t.substr(0, e) : t, t.numberToThousand = (t, e = ",") => xt(t) || z(t) ? t : isNaN(Number(t)) ? NaN : t.toString().replace(/\d+/, t => t.replace(/(\d)(?=(\d{3})+$)/g, t => `${t}${e}`)), t.parseParams = t => _(t).join("/"), t.querystring = Yt, t.reduceMultiple = (t, e, n) => fe(t)(e, n), t.reduceParams = t => {
      if (!t) return {};
      if (t instanceof FormData) return t;
      return dt(t => !z(t) && !xt(t))(t) || {};
    }, t.remove = function (t, e) {
      const n = [];
      if (!t || !t.length) return n;
      let r = -1,
          o = [],
          i = t.length;

      for (; ++r < i;) {
        const i = t[r];
        e(i, r, t) && (n.push(i), o.push(r));
      }

      return function (t, e) {
        let n = t ? e.length : 0,
            r = n - 1,
            o = 0;

        for (; n--;) {
          const i = e[n];
          n != r && i === o || (o = i, Array.prototype.splice.call(t, i, 1));
        }
      }(t, o), n;
    }, t.split = Dt, t.sum = (t, e) => {
      let n = new ce(0);

      const r = (t, e) => {
        "array" === le(t) && Array.isArray(t) && t.forEach(t => {
          isNaN(t) || (n = n.plus(Number(t))), "object" === le(t) && void 0 !== e && null !== t[e] && (n = n.plus(Number(t[e]))), "array" === le(t) && Array.isArray(t) && r(t, e);
        });
      };

      return r(t, e), Number(n);
    }, t.throttle = function (t, e, n) {
      let r = !0,
          o = !0;
      if ("function" != typeof t) throw new TypeError("Expected a function");
      return Me(n) && (r = "leading" in n ? !!n.leading : r, o = "trailing" in n ? !!n.trailing : o), Te(t, e, {
        leading: r,
        trailing: o,
        maxWait: e
      });
    }, t.toDate = t => zt(t) ? new Date(t).getTime() : 0, t.translateMapToArray = t => {
      let e = [];

      for (const [n, r] of t.entries()) e.push({
        label: r,
        value: n
      });

      return e;
    }, t.treeReduce = Bt, t.trimAll = It, t.trimParams = de, t.unLoadScript = function (t) {
      if (document.getElementById(t)) {
        const e = document.getElementById(t);
        document.body.removeChild(e);
      }
    }, t.uuidv4 = () => be(), t.wanToyuan = (t, e) => se(1e4)(t, e), t.yuanTofen = (t, e) => se(100)(t, e), t.yuanTowan = (t, e) => fe(1e4)(t, e), Object.defineProperty(t, "__esModule", {
      value: !0
    });
  });
})(ywfeUtils_umd, ywfeUtils_umd.exports);

const USER_UNLOGIN = 17020001;
const USER_TOKEN_INVALID = 17020002;
const USER_TOKEN_NULL = 17020003;
const TOKEN_FAIL_OLD_1 = -2;
const TOKEN_FAIL_OLD_2 = 1000;
const BIZ_MODULE_NOTFOUND = 17031000;
const GO_TO_LOGIN = [
    USER_UNLOGIN,
    USER_TOKEN_INVALID,
    USER_TOKEN_NULL,
    TOKEN_FAIL_OLD_1,
    TOKEN_FAIL_OLD_2,
];
const NO_MESSAGE = [BIZ_MODULE_NOTFOUND];

const instance = axios.create({
    timeout: 30 * 1000,
});
instance.interceptors.request.use(config => {
    const configData = config;
    if (typeof window !== 'undefined') {
        const token = localStorage.getItem('token') || '';
        configData.headers = Object.assign(Object.assign({}, configData.headers), { 'X-TOKEN': token });
    }
    return configData;
}, error => {
    return Promise.reject(error);
});
instance.interceptors.response.use((res) => {
    const { data, config } = res;
    const { success, code } = data;
    const isFormData = typeof data === 'string';
    const isArraybuffer = res.config.responseType === 'arraybuffer';
    if (isFormData || isArraybuffer) {
        if (data) {
            return data;
        }
        else {
            if (typeof window !== 'undefined') {
                antd.message.error(isFormData ? '图片上传失败' : '下载失败');
            }
            return Promise.reject();
        }
    }
    if (success) {
        return data.data || success;
    }
    else {
        if (GO_TO_LOGIN.indexOf(Number(code)) >= 0 &&
            typeof window !== 'undefined') {
            const projectId = window.localStorage.getItem('projectId');
            const { loginHost = '' } = config;
            let pathname = window.location.pathname;
            let search = window.location.search;
            search = search.replace('?', '');
            let query = ywfeUtils_umd.exports.querystring.parse(search);
            query = Object.assign(Object.assign({}, query), { projectId: projectId || query.projectId });
            let loginHostNew = loginHost;
            // 针对电虎独立站の登录跳转(勿删！！！)
            if (window.location.host === 'dianhu.ywwl.com') {
                loginHostNew = `${window.location.protocol}//yun.ywwl.com`;
            }
            else if (window.location.host == 'dianhu-test.ywwl.com') {
                loginHostNew = `${window.location.protocol}//yun-test.ywwl.com`;
            }
            else if (window.location.host == 'dianhu-dev.ywwl.com') {
                loginHostNew = `${window.location.protocol}//yun-dev.ywwl.com`;
            }
            window.top.location.href = `${loginHostNew}/login?${ywfeUtils_umd.exports.querystring.stringify(query)}&pathname=${encodeURIComponent(pathname)}&targetUrl=${encodeURIComponent(window.location.pathname + window.location.search)}`;
        }
        if (typeof window !== 'undefined' && NO_MESSAGE.indexOf(code) < 0) {
            antd.message.error(data.msg || data.message);
        }
        return Promise.reject(data);
    }
}, (error) => {
    if (typeof window !== 'undefined') {
        antd.message.error('网络繁忙, 休息一会儿再来吧~ ^_^！');
    }
    return Promise.reject(error);
});
class Request {
    static get(url, config) {
        return instance.get(url, config);
    }
    static post(url, data, config) {
        return instance.post(url, data, config);
    }
}

module.exports = Request;
//# sourceMappingURL=ywfe-request.cjs.js.map
